@@ -93,8 +93,8 @@ class AbstractSettingsMaskedInterferometer(
 ):
     def __init__(
         self,
-        grid_class=grids.Grid,
-        grid_inversion_class=grids.Grid,
+        grid_class=grids.Grid2D,
+        grid_inversion_class=grids.Grid2D,
         sub_size=2,
         fractional_accuracy=0.9999,
         sub_steps=None,
@@ -111,23 +111,23 @@ class AbstractSettingsMaskedInterferometer(
 
           Parameters
           ----------
-        grid_class : ag.Grid
-            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid`,
-            `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a description of these options).
-        grid_inversion_class : ag.Grid
+        grid_class : ag.Grid2D
+            The type of grid used to create the image from the `Galaxy` and `Plane`. The options are `Grid2D`,
+            `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a description of these options).
+        grid_inversion_class : ag.Grid2D
             The type of grid used to create the grid that maps the `Inversion` source pixels to the data's image-pixels.
-            The options are `Grid`, `GridIterate` and `GridInterpolate` (see the `Grid` documentation for a
+            The options are `Grid2D`, `Grid2DIterate` and `Grid2DInterpolate` (see the `Grid2D` documentation for a
             description of these options).
         sub_size : int
-            If the grid and / or grid_inversion use a `Grid`, this sets the sub-size used by the `Grid`.
+            If the grid and / or grid_inversion use a `Grid2D`, this sets the sub-size used by the `Grid2D`.
         fractional_accuracy : float
-            If the grid and / or grid_inversion use a `GridIterate`, this sets the fractional accuracy it
+            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the fractional accuracy it
             uses when evaluating functions.
         sub_steps : [int]
-            If the grid and / or grid_inversion use a `GridIterate`, this sets the steps the sub-size is increased by
+            If the grid and / or grid_inversion use a `Grid2DIterate`, this sets the steps the sub-size is increased by
             to meet the fractional accuracy when evaluating functions.
         pixel_scales_interp : float or (float, float)
-            If the grid and / or grid_inversion use a `GridInterpolate`, this sets the resolution of the interpolation
+            If the grid and / or grid_inversion use a `Grid2DInterpolate`, this sets the resolution of the interpolation
             grid.
         signal_to_noise_limit : float
             If input, the dataset's noise-map is rescaled such that no pixel has a signal-to-noise above the
@@ -280,7 +280,7 @@ class Interferometer(AbstractInterferometer):
 
         if positions_path is not None:
 
-            positions = grids.GridIrregularGrouped.from_file(file_path=positions_path)
+            positions = grids.Grid2DIrregularGrouped.from_file(file_path=positions_path)
 
         else:
 
@@ -343,7 +343,7 @@ class AbstractSimulatorInterferometer:
 
         Parameters
         ----------
-        real_space_shape_2d : (int, int)
+        real_space_shape_native : (int, int)
             The shape of the observation. Note that we do not simulator a full Imaging frame (e.g. 2000 x 2000 pixels for \
             Hubble imaging), but instead just a cut-out around the strong lens.
         real_space_pixel_scales : float
@@ -392,9 +392,9 @@ class AbstractSimulatorInterferometer:
             uv_wavelengths=self.uv_wavelengths, real_space_mask=image.mask
         )
 
-        background_sky_map = arrays.Array.full(
+        background_sky_map = arrays.Array2D.full(
             fill_value=self.background_sky_level,
-            shape_2d=image.shape_2d,
+            shape_native=image.shape_native,
             pixel_scales=image.pixel_scales,
         )
 
@@ -407,12 +407,12 @@ class AbstractSimulatorInterferometer:
                 data=visibilities, sigma=self.noise_sigma, seed=self.noise_seed
             )
             noise_map = vis.VisibilitiesNoiseMap.full(
-                fill_value=self.noise_sigma, shape_1d=(visibilities.shape[0],)
+                fill_value=self.noise_sigma, shape_slim=(visibilities.shape[0],)
             )
         else:
             noise_map = vis.VisibilitiesNoiseMap.full(
                 fill_value=self.noise_if_add_noise_false,
-                shape_1d=(visibilities.shape[0],),
+                shape_slim=(visibilities.shape[0],),
             )
 
         if np.isnan(noise_map).any():
