@@ -12,6 +12,7 @@ from autoarray.util import inversion_util
 from scipy.interpolate import griddata
 from scipy import sparse
 import pylops
+import typing
 
 
 class SettingsInversion:
@@ -51,7 +52,12 @@ class SettingsInversion:
         return ""
 
 
-def inversion(masked_dataset, mapper, regularization, settings=SettingsInversion()):
+def inversion(
+    masked_dataset,
+    mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
+    regularization,
+    settings=SettingsInversion(),
+):
 
     if isinstance(masked_dataset, imaging.MaskedImaging):
 
@@ -98,32 +104,11 @@ def log_determinant_of_matrix_cholesky(matrix):
         raise exc.InversionException()
 
 
-class AbstractInversionMatrix:
-    def __init__(
-        self, curvature_reg_matrix: np.ndarray, regularization_matrix: np.ndarray
-    ):
-
-        self.curvature_reg_matrix = curvature_reg_matrix
-        self.regularization_matrix = regularization_matrix
-
-    @property
-    def log_det_curvature_reg_matrix_term(self):
-        return log_determinant_of_matrix_cholesky(self.curvature_reg_matrix)
-
-    @property
-    def errors_with_covariance(self):
-        return np.linalg.inv(self.curvature_reg_matrix)
-
-    @property
-    def errors(self):
-        return np.diagonal(self.errors_with_covariance)
-
-
 class AbstractInversion:
     def __init__(
         self,
         noise_map: np.ndarray,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         regularization_matrix: np.ndarray,
         reconstruction: np.ndarray,
@@ -137,23 +122,23 @@ class AbstractInversion:
         self.reconstruction = reconstruction
         self.settings = settings
 
-    def interpolated_reconstruction_from_shape_2d(self, shape_2d=None):
-        return self.interpolated_values_from_shape_2d(
-            values=self.reconstruction, shape_2d=shape_2d
+    def interpolated_reconstructed_data_from_shape_native(self, shape_native=None):
+        return self.interpolated_values_from_shape_native(
+            values=self.reconstruction, shape_native=shape_native
         )
 
-    def interpolated_errors_from_shape_2d(self, shape_2d=None):
-        return self.interpolated_values_from_shape_2d(
-            values=self.errors, shape_2d=shape_2d
+    def interpolated_errors_from_shape_native(self, shape_native=None):
+        return self.interpolated_values_from_shape_native(
+            values=self.errors, shape_native=shape_native
         )
 
-    def interpolated_values_from_shape_2d(self, values, shape_2d=None):
+    def interpolated_values_from_shape_native(self, values, shape_native=None):
 
-        if shape_2d is not None:
+        if shape_native is not None:
 
-            grid = grids.Grid.bounding_box(
-                bounding_box=self.mapper.pixelization_grid.extent,
-                shape_2d=shape_2d,
+            grid = grids.Grid2D.bounding_box(
+                bounding_box=self.mapper.source_pixelization_grid.extent,
+                shape_native=shape_native,
                 buffer_around_corners=False,
             )
 
@@ -162,7 +147,7 @@ class AbstractInversion:
             in "image_grid"
         ):
 
-            grid = self.mapper.grid
+            grid = self.mapper.source_grid_slim
 
         elif (
             conf.instance["general"]["inversion"]["interpolated_grid_shape"]
@@ -170,11 +155,11 @@ class AbstractInversion:
         ):
 
             dimension = int(np.sqrt(self.mapper.pixels))
-            shape_2d = (dimension, dimension)
+            shape_native = (dimension, dimension)
 
-            grid = grids.Grid.bounding_box(
-                bounding_box=self.mapper.pixelization_grid.extent,
-                shape_2d=shape_2d,
+            grid = grids.Grid2D.bounding_box(
+                bounding_box=self.mapper.source_pixelization_grid.extent,
+                shape_native=shape_native,
                 buffer_around_corners=False,
             )
 
@@ -186,15 +171,15 @@ class AbstractInversion:
             )
 
         interpolated_reconstruction = griddata(
-            points=self.mapper.pixelization_grid,
+            points=self.mapper.source_pixelization_grid,
             values=values,
-            xi=grid.in_2d_binned,
+            xi=grid.native_binned,
             method="linear",
         )
 
         interpolated_reconstruction[np.isnan(interpolated_reconstruction)] = 0.0
 
-        return arrays.Array.manual(
+        return arrays.Array2D.manual(
             array=interpolated_reconstruction, pixel_scales=grid.pixel_scales
         )
 
@@ -226,18 +211,65 @@ class AbstractInversion:
 
     @property
     def brightest_reconstruction_pixel_centre(self):
-        return grids.GridIrregular(
-            grid=[self.mapper.pixelization_grid[self.brightest_reconstruction_pixel]]
+        return grids.Grid2DIrregular(
+            grid=[
+                self.mapper.source_pixelization_grid[
+                    self.brightest_reconstruction_pixel
+                ]
+            ]
         )
 
+    @property
+    def mapped_reconstructed_image(self):
+        raise NotImplementedError()
+
+    @property
+    def residual_map(self):
+        raise NotImplementedError()
+
+    @property
+    def normalized_residual_map(self):
+        raise NotImplementedError()
+
+    @property
+    def chi_squared_map(self):
+        raise NotImplementedError()
+
+    @property
+    def regularization_weights(self):
+        return self.regularization.regularization_weights_from_mapper(
+            mapper=self.mapper
+        )
+
+
+class AbstractInversionMatrix:
+    def __init__(
+        self, curvature_reg_matrix: np.ndarray, regularization_matrix: np.ndarray
+    ):
+
+        self.curvature_reg_matrix = curvature_reg_matrix
+        self.regularization_matrix = regularization_matrix
+
+    @property
+    def log_det_curvature_reg_matrix_term(self):
+        return log_determinant_of_matrix_cholesky(self.curvature_reg_matrix)
+
+    @property
+    def errors_with_covariance(self):
+        return np.linalg.inv(self.curvature_reg_matrix)
+
+    @property
+    def errors(self):
+        return np.diagonal(self.errors_with_covariance)
+
 
 class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
     def __init__(
         self,
-        image: arrays.Array,
-        noise_map: arrays.Array,
+        image: arrays.Array2D,
+        noise_map: arrays.Array2D,
         convolver: conv.Convolver,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         blurred_mapping_matrix: np.ndarray,
         regularization_matrix: np.ndarray,
@@ -303,10 +335,10 @@ class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
     @classmethod
     def from_data_mapper_and_regularization(
         cls,
-        image: arrays.Array,
-        noise_map: arrays.Array,
+        image: arrays.Array2D,
+        noise_map: arrays.Array2D,
         convolver: conv.Convolver,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         settings=SettingsInversion(),
     ):
@@ -361,10 +393,10 @@ class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
             reconstruction=self.reconstruction,
         )
 
-        return arrays.Array(
+        return arrays.Array2D(
             array=reconstructed_image,
-            mask=self.mapper.grid.mask.mask_sub_1,
-            store_in_1d=True,
+            mask=self.mapper.source_grid_slim.mask.mask_sub_1,
+            store_slim=True,
         )
 
     @property
@@ -372,8 +404,8 @@ class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
         return inversion_util.inversion_residual_map_from(
             pixelization_values=self.reconstruction,
             data=self.image,
-            mask_1d_index_for_sub_mask_1d_index=self.mapper.grid.mask.regions._mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=self.mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=self.mapper.source_grid_slim.mask._slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=self.mapper.all_sub_slim_indexes_for_pixelization_index,
         )
 
     @property
@@ -382,8 +414,8 @@ class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
             pixelization_values=self.reconstruction,
             data=self.image,
             noise_map_1d=self.noise_map,
-            mask_1d_index_for_sub_mask_1d_index=self.mapper.grid.mask.regions._mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=self.mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=self.mapper.source_grid_slim.mask._slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=self.mapper.all_sub_slim_indexes_for_pixelization_index,
         )
 
     @property
@@ -392,8 +424,8 @@ class InversionImagingMatrix(AbstractInversion, AbstractInversionMatrix):
             pixelization_values=self.reconstruction,
             data=self.image,
             noise_map_1d=self.noise_map,
-            mask_1d_index_for_sub_mask_1d_index=self.mapper.grid.mask.regions._mask_1d_index_for_sub_mask_1d_index,
-            all_sub_mask_1d_indexes_for_pixelization_1d_index=self.mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index,
+            slim_index_for_sub_slim_index=self.mapper.source_grid_slim.mask._slim_index_for_sub_slim_index,
+            all_sub_slim_indexes_for_pixelization_index=self.mapper.all_sub_slim_indexes_for_pixelization_index,
         )
 
 
@@ -403,7 +435,7 @@ class AbstractInversionInterferometer(AbstractInversion):
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         regularization_matrix: np.ndarray,
         reconstruction: np.ndarray,
@@ -428,7 +460,7 @@ class AbstractInversionInterferometer(AbstractInversion):
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         settings=SettingsInversion(use_linear_operators=True),
     ):
@@ -460,10 +492,10 @@ class AbstractInversionInterferometer(AbstractInversion):
             reconstruction=self.reconstruction,
         )
 
-        return arrays.Array(
+        return arrays.Array2D(
             array=mapped_reconstructed_image,
-            mask=self.mapper.grid.mask.mask_sub_1,
-            store_in_1d=True,
+            mask=self.mapper.source_grid_slim.mask.mask_sub_1,
+            store_slim=True,
         )
 
 
@@ -475,7 +507,7 @@ class InversionInterferometerMatrix(
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         regularization_matrix: np.ndarray,
         reconstruction: np.ndarray,
@@ -545,7 +577,7 @@ class InversionInterferometerMatrix(
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         settings=SettingsInversion(),
     ):
@@ -640,7 +672,7 @@ class InversionInterferometerLinearOperator(AbstractInversionInterferometer):
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         regularization_matrix: np.ndarray,
         reconstruction: np.ndarray,
@@ -702,7 +734,7 @@ class InversionInterferometerLinearOperator(AbstractInversionInterferometer):
         visibilities: vis.Visibilities,
         noise_map: vis.VisibilitiesNoiseMap,
         transformer: trans.TransformerNUFFT,
-        mapper: mappers.Mapper,
+        mapper: typing.Union[mappers.MapperRectangular, mappers.MapperVoronoi],
         regularization: reg.Regularization,
         settings=SettingsInversion(),
     ):
