@@ -15,22 +15,22 @@ def sub_steps_from_none(sub_steps):
     return sub_steps
 
 
-class GridIterate(abstract_grid.AbstractGrid):
+class Grid2DIterate(abstract_grid.AbstractGrid2D):
     def __new__(
         cls,
         grid,
         mask,
         fractional_accuracy=0.9999,
         sub_steps=None,
-        store_in_1d=True,
+        store_slim=True,
         *args,
         **kwargs,
     ):
-        """Represents a grid of coordinates as described for the `Grid` class, but using an iterative sub-grid that
+        """Represents a grid of coordinates as described for the `Grid2D` class, but using an iterative sub-grid that
         adapts its resolution when it is input into a function that performs an analytic calculation.
 
-        A `Grid` represents (y,x) coordinates using a sub-grid, where functions are evaluated once at every coordinate
-        on the sub-grid and averaged to give a more precise evaluation an analytic function. A `GridIterate` does not
+        A `Grid2D` represents (y,x) coordinates using a sub-grid, where functions are evaluated once at every coordinate
+        on the sub-grid and averaged to give a more precise evaluation an analytic function. A `Grid2DIterate` does not
         have a specified sub-grid size, but instead iteratively recomputes the analytic function at increasing sub-grid
         sizes until an input fractional accuracy is reached.
 
@@ -39,7 +39,7 @@ class GridIterate(abstract_grid.AbstractGrid):
         fractional accuracy. For functions where a wide range of sub-grid sizes allow fractional accuracy to be met
         this ensures the function can be evaluated accurate in a computaionally efficient manner.
 
-        This overcomes a limitation of the `Grid` class whereby if a small subset of pixels require high levels of
+        This overcomes a limitation of the `Grid2D` class whereby if a small subset of pixels require high levels of
         sub-gridding to be evaluated accuracy, the entire grid would require this sub-grid size thus leading to
         unecessary expensive function evaluations.
 
@@ -56,23 +56,23 @@ class GridIterate(abstract_grid.AbstractGrid):
         sub_steps : [int] or None
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
 
         sub_steps = sub_steps_from_none(sub_steps=sub_steps)
-        if store_in_1d and len(grid.shape) != 2:
+        if store_slim and len(grid.shape) != 2:
             raise exc.GridException(
-                "An grid input into the grids.Grid.__new__ method has store_in_1d = `True` but"
+                "An grid input into the grids.Grid2D.__new__ method has store_slim = `True` but"
                 "the input shape of the array is not 1."
             )
 
         obj = grid.view(cls)
         obj.mask = mask
-        obj.store_in_1d = store_in_1d
-        obj.grid = grids.Grid.manual_mask(
-            grid=np.asarray(obj), mask=mask, store_in_1d=store_in_1d
+        obj.store_slim = store_slim
+        obj.grid = grids.Grid2D.manual_mask(
+            grid=np.asarray(obj), mask=mask, store_slim=store_slim
         )
         obj.fractional_accuracy = fractional_accuracy
         obj.sub_steps = sub_steps
@@ -80,7 +80,7 @@ class GridIterate(abstract_grid.AbstractGrid):
 
     def __array_finalize__(self, obj):
 
-        super(GridIterate, self).__array_finalize__(obj)
+        super(Grid2DIterate, self).__array_finalize__(obj)
 
         if hasattr(obj, "grid"):
             self.grid = obj.grid
@@ -91,11 +91,11 @@ class GridIterate(abstract_grid.AbstractGrid):
         if hasattr(obj, "sub_steps"):
             self.sub_steps = obj.sub_steps
 
-    def _new_structure(self, grid, mask, store_in_1d):
-        """Conveninence method for creating a new instance of the GridIterate class from this grid.
+    def _new_structure(self, grid, mask, store_slim):
+        """Conveninence method for creating a new instance of the Grid2DIterate class from this grid.
 
-        This method is used in the 'in_1d', 'in_2d', etc. convenience methods. By overwritin this method such that a
-        GridIterate is created the in_1d and in_2d methods will return instances of the GridIterate.
+        This method is used in the 'slim', 'native', etc. convenience methods. By overwritin this method such that a
+        Grid2DIterate is created the slim and native methods will return instances of the Grid2DIterate.
 
         Parameters
         ----------
@@ -104,44 +104,44 @@ class GridIterate(abstract_grid.AbstractGrid):
         mask : msk.Mask2D
             The 2D mask associated with the grid, defining the pixels each grid coordinate is paired with and
             originates from.
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
-        return GridIterate(
+        return Grid2DIterate(
             grid=grid,
             mask=mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
-    def manual_1d(
+    def manual_slim(
         cls,
         grid,
-        shape_2d,
+        shape_native,
         pixel_scales,
         origin=(0.0, 0.0),
         fractional_accuracy=0.9999,
         sub_steps=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create a GridIterate (see *GridIterate.__new__*) by inputting the grid coordinates in 1D, for example:
+        """Create a Grid2DIterate (see *Grid2DIterate.__new__*) by inputting the grid coordinates in 1D, for example:
 
             grid=np.array([[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]])
 
             grid=[[1.0, 1.0], [2.0, 2.0], [3.0, 3.0], [4.0, 4.0]]
 
-        From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the shape_2d must be
-        input into this method. The mask is setup as a unmasked `Mask2D` of shape_2d.
+        From 1D input the method cannot determine the 2D shape of the grid and its mask, thus the shape_native must be
+        input into this method. The mask is setup as a unmasked `Mask2D` of shape_native.
 
         Parameters
         ----------
         grid : np.ndarray or list
             The (y,x) coordinates of the grid input as an ndarray of shape [total_unmasked_pixells*(sub_size**2), 2]
             or a list of lists.
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the mask the grid is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -154,7 +154,7 @@ class GridIterate(abstract_grid.AbstractGrid):
             they are setup as the default values [2, 4, 8, 16].
         origin : (float, float)
             The origin of the grid's mask.
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
@@ -162,44 +162,49 @@ class GridIterate(abstract_grid.AbstractGrid):
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
         mask = msk.Mask2D.unmasked(
-            shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=1, origin=origin
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            sub_size=1,
+            origin=origin,
         )
 
-        if store_in_1d:
-            return GridIterate(
+        if store_slim:
+            return Grid2DIterate(
                 grid=grid,
                 mask=mask,
                 fractional_accuracy=fractional_accuracy,
                 sub_steps=sub_steps,
-                store_in_1d=store_in_1d,
+                store_slim=store_slim,
             )
 
-        grid_2d = grid_util.sub_grid_2d_from(sub_grid_1d=grid, mask=mask, sub_size=1)
+        grid_2d = grid_util.sub_grid_2d_from(
+            sub_grid_2d_slim=grid, mask_2d=mask, sub_size=1
+        )
 
-        return GridIterate(
+        return Grid2DIterate(
             grid=grid_2d,
             mask=mask,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def uniform(
         cls,
-        shape_2d,
+        shape_native,
         pixel_scales,
         origin=(0.0, 0.0),
         fractional_accuracy=0.9999,
         sub_steps=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
-        """Create a GridIterate (see *GridIterate.__new__*) as a uniform grid of (y,x) values given an input
-        shape_2d and pixel scale of the grid:
+        """Create a Grid2DIterate (see *Grid2DIterate.__new__*) as a uniform grid of (y,x) values given an input
+        shape_native and pixel scale of the grid:
 
         Parameters
         ----------
-        shape_2d : (float, float)
+        shape_native : (float, float)
             The 2D shape of the uniform grid and the mask that it is paired with.
         pixel_scales: (float, float) or float
             The (y,x) scaled units to pixel units conversion factors of every pixel. If this is input as a ``float``,
@@ -212,32 +217,35 @@ class GridIterate(abstract_grid.AbstractGrid):
             they are setup as the default values [2, 4, 8, 16].
         origin : (float, float)
             The origin of the grid's mask.
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
 
         pixel_scales = geometry_util.convert_pixel_scales_2d(pixel_scales=pixel_scales)
 
-        grid_1d = grid_util.grid_1d_via_shape_2d_from(
-            shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=1, origin=origin
+        grid_slim = grid_util.grid_2d_slim_via_shape_native_from(
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            sub_size=1,
+            origin=origin,
         )
 
-        return GridIterate.manual_1d(
-            grid=grid_1d,
-            shape_2d=shape_2d,
+        return Grid2DIterate.manual_slim(
+            grid=grid_slim,
+            shape_native=shape_native,
             pixel_scales=pixel_scales,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
             origin=origin,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def from_mask(
-        cls, mask, fractional_accuracy=0.9999, sub_steps=None, store_in_1d=True
+        cls, mask, fractional_accuracy=0.9999, sub_steps=None, store_slim=True
     ):
-        """Create a GridIterate (see *GridIterate.__new__*) from a mask, where only unmasked pixels are included in
+        """Create a Grid2DIterate (see *Grid2DIterate.__new__*) from a mask, where only unmasked pixels are included in
         the grid (if the grid is represented in 2D masked values are (0.0, 0.0)).
 
         The mask's pixel_scales and origin properties are used to compute the grid (y,x) coordinates.
@@ -252,58 +260,58 @@ class GridIterate(abstract_grid.AbstractGrid):
         sub_steps : [int] or None
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
 
-        grid_1d = grid_util.grid_1d_via_mask_from(
-            mask=mask, pixel_scales=mask.pixel_scales, sub_size=1, origin=mask.origin
+        grid_slim = grid_util.grid_2d_slim_via_mask_from(
+            mask_2d=mask, pixel_scales=mask.pixel_scales, sub_size=1, origin=mask.origin
         )
 
-        if store_in_1d:
-            return grids.GridIterate(
-                grid=grid_1d,
+        if store_slim:
+            return grids.Grid2DIterate(
+                grid=grid_slim,
                 mask=mask.mask_sub_1,
                 fractional_accuracy=fractional_accuracy,
                 sub_steps=sub_steps,
-                store_in_1d=store_in_1d,
+                store_slim=store_slim,
             )
 
         grid_2d = grid_util.sub_grid_2d_from(
-            sub_grid_1d=grid_1d, mask=mask.mask_sub_1, sub_size=1
+            sub_grid_2d_slim=grid_slim, mask_2d=mask.mask_sub_1, sub_size=1
         )
 
-        return grids.GridIterate(
+        return grids.Grid2DIterate(
             grid=grid_2d,
             mask=mask.mask_sub_1,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     @classmethod
     def blurring_grid_from_mask_and_kernel_shape(
         cls,
         mask,
-        kernel_shape_2d,
+        kernel_shape_native,
         fractional_accuracy=0.9999,
         sub_steps=None,
-        store_in_1d=True,
+        store_slim=True,
     ):
         """Setup a blurring-grid from a mask, where a blurring grid consists of all pixels that are masked (and
         therefore have their values set to (0.0, 0.0)), but are close enough to the unmasked pixels that their values
         will be convolved into the unmasked those pixels. This occurs in *PyAutoGalaxy* when computing images from
         light profile objects.
 
-        See *grids.Grid.blurring_grid_from_mask_and_kernel_shape* for a full description of a blurring grid. This
-        method creates the blurring grid as a GridIterate.
+        See *grids.Grid2D.blurring_grid_from_mask_and_kernel_shape* for a full description of a blurring grid. This
+        method creates the blurring grid as a Grid2DIterate.
 
         Parameters
         ----------
         mask : Mask2D
             The mask whose masked pixels are used to setup the blurring grid.
-        kernel_shape_2d : (float, float)
+        kernel_shape_native : (float, float)
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         fractional_accuracy : float
             The fractional accuracy the function evaluated must meet to be accepted, where this accuracy is the ratio
@@ -311,25 +319,25 @@ class GridIterate(abstract_grid.AbstractGrid):
         sub_steps : [int] or None
             The sub-size values used to iteratively evaluated the function at high levels of sub-gridding. If None,
             they are setup as the default values [2, 4, 8, 16].
-        store_in_1d : bool
+        store_slim : bool
             If True, the grid is stored in 1D as an ndarray of shape [total_unmasked_pixels, 2]. If False, it is
             stored in 2D as an ndarray of shape [total_y_pixels, total_x_pixels, 2].
         """
 
-        blurring_mask = mask.regions.blurring_mask_from_kernel_shape(
-            kernel_shape_2d=kernel_shape_2d
+        blurring_mask = mask.blurring_mask_from_kernel_shape(
+            kernel_shape_native=kernel_shape_native
         )
 
         return cls.from_mask(
             mask=blurring_mask,
             fractional_accuracy=fractional_accuracy,
             sub_steps=sub_steps,
-            store_in_1d=store_in_1d,
+            store_slim=store_slim,
         )
 
     def grid_from_deflection_grid(self, deflection_grid):
         """
-        Returns a new GridIterate from this grid, where the (y,x) coordinates of this grid have a grid of (y,x) values,
+        Returns a new Grid2DIterate from this grid, where the (y,x) coordinates of this grid have a grid of (y,x) values,
              termed the deflection grid, subtracted from them to determine the new grid of (y,x) values.
 
             This is used by PyAutoLens to perform grid ray-tracing.
@@ -339,35 +347,35 @@ class GridIterate(abstract_grid.AbstractGrid):
             deflection_grid : np.ndarray
                 The grid of (y,x) coordinates which is subtracted from this grid.
         """
-        return GridIterate(
+        return Grid2DIterate(
             grid=self - deflection_grid,
             mask=self.mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
-            store_in_1d=self.store_in_1d,
+            store_slim=self.store_slim,
         )
 
-    def blurring_grid_from_kernel_shape(self, kernel_shape_2d):
+    def blurring_grid_from_kernel_shape(self, kernel_shape_native):
         """
-        Returns the blurring grid from a grid and create it as a GridIterate, via an input 2D kernel shape.
+        Returns the blurring grid from a grid and create it as a Grid2DIterate, via an input 2D kernel shape.
 
             For a full description of blurring grids, checkout *blurring_grid_from_mask_and_kernel_shape*.
 
             Parameters
             ----------
-            kernel_shape_2d : (float, float)
+            kernel_shape_native : (float, float)
                 The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
 
-        return GridIterate.blurring_grid_from_mask_and_kernel_shape(
+        return Grid2DIterate.blurring_grid_from_mask_and_kernel_shape(
             mask=self.mask,
-            kernel_shape_2d=kernel_shape_2d,
+            kernel_shape_native=kernel_shape_native,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
-            store_in_1d=self.store_in_1d,
+            store_slim=self.store_slim,
         )
 
-    def padded_grid_from_kernel_shape(self, kernel_shape_2d):
+    def padded_grid_from_kernel_shape(self, kernel_shape_native):
         """When the edge pixels of a mask are unmasked and a convolution is to occur, the signal of edge pixels will be
         'missing' if the grid is used to evaluate the signal via an analytic function.
 
@@ -376,23 +384,23 @@ class GridIterate(abstract_grid.AbstractGrid):
 
         Parameters
         ----------
-        kernel_shape_2d : (float, float)
+        kernel_shape_native : (float, float)
             The 2D shape of the kernel which convolves signal from masked pixels to unmasked pixels.
         """
         shape = self.mask.shape
 
         padded_shape = (
-            shape[0] + kernel_shape_2d[0] - 1,
-            shape[1] + kernel_shape_2d[1] - 1,
+            shape[0] + kernel_shape_native[0] - 1,
+            shape[1] + kernel_shape_native[1] - 1,
         )
 
         padded_mask = msk.Mask2D.unmasked(
-            shape_2d=padded_shape,
+            shape_native=padded_shape,
             pixel_scales=self.mask.pixel_scales,
             sub_size=self.mask.sub_size,
         )
 
-        return grids.GridIterate.from_mask(
+        return grids.Grid2DIterate.from_mask(
             mask=padded_mask,
             fractional_accuracy=self.fractional_accuracy,
             sub_steps=self.sub_steps,
@@ -403,25 +411,25 @@ class GridIterate(abstract_grid.AbstractGrid):
 
         mask_higher_sub = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=sub_size)
 
-        grid_compute = grids.Grid.from_mask(mask=mask_higher_sub)
+        grid_compute = grids.Grid2D.from_mask(mask=mask_higher_sub)
         array_higher_sub = func(cls, grid_compute)
-        return grid_compute.structure_from_result(result=array_higher_sub).in_2d_binned
+        return grid_compute.structure_from_result(result=array_higher_sub).native_binned
 
     @staticmethod
     def grid_at_sub_size_from_func_and_mask(func, cls, mask, sub_size):
 
         mask_higher_sub = mask.mask_new_sub_size_from_mask(mask=mask, sub_size=sub_size)
 
-        grid_compute = grids.Grid.from_mask(mask=mask_higher_sub)
+        grid_compute = grids.Grid2D.from_mask(mask=mask_higher_sub)
         grid_higher_sub = func(cls, grid_compute)
-        return grid_compute.structure_from_result(result=grid_higher_sub).in_2d_binned
+        return grid_compute.structure_from_result(result=grid_higher_sub).native_binned
 
     def fractional_mask_from_arrays(
         self, array_lower_sub_2d, array_higher_sub_2d
     ) -> msk.Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
-            value in the result array is within the `GridIterate`'s specified fractional accuracy. The fractional mask thus
+            value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
             determines whether a pixel on the grid needs to be reevaluated at a higher level of sub-gridding to meet the
             specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is `False`.
 
@@ -431,14 +439,14 @@ class GridIterate(abstract_grid.AbstractGrid):
 
             Parameters
             ----------
-            array_lower_sub_2d : arrays.Array
+            array_lower_sub_2d : arrays.Array2D
                 The results computed by a function using a lower sub-grid size
-            array_higher_sub_2d : arrays.Array
+            array_higher_sub_2d : arrays.Array2D
                 The results computed by a function using a higher sub-grid size.
         """
 
         fractional_mask = msk.Mask2D.unmasked(
-            shape_2d=array_lower_sub_2d.shape_2d,
+            shape_native=array_lower_sub_2d.shape_native,
             pixel_scales=array_lower_sub_2d.pixel_scales,
             invert=True,
         )
@@ -520,15 +528,15 @@ class GridIterate(abstract_grid.AbstractGrid):
             The function which is iterated over to compute a more precise evaluation.
         cls : cls
             The class the function belongs to.
-        grid_lower_sub_2d : arrays.Array
+        grid_lower_sub_2d : arrays.Array2D
             The results computed by the function using a lower sub-grid size
         """
         from autoarray.structures import arrays
 
         if not np.any(array_lower_sub_2d):
-            return array_lower_sub_2d.in_1d
+            return array_lower_sub_2d.slim
 
-        iterated_array = np.zeros(shape=self.shape_2d)
+        iterated_array = np.zeros(shape=self.shape_native)
 
         fractional_mask_lower_sub = self.mask
 
@@ -552,12 +560,12 @@ class GridIterate(abstract_grid.AbstractGrid):
 
             if fractional_mask_higher_sub.is_all_true:
 
-                iterated_array_1d = array_util.sub_array_1d_from(
-                    mask=self.mask, sub_array_2d=iterated_array, sub_size=1
+                iterated_array_1d = array_util.sub_array_2d_slim_from(
+                    mask_2d=self.mask, sub_array_2d=iterated_array, sub_size=1
                 )
 
-                return arrays.Array(
-                    array=iterated_array_1d, mask=self.mask.mask_sub_1, store_in_1d=True
+                return arrays.Array2D(
+                    array=iterated_array_1d, mask=self.mask.mask_sub_1, store_slim=True
                 )
 
             array_lower_sub_2d = array_higher_sub
@@ -570,14 +578,14 @@ class GridIterate(abstract_grid.AbstractGrid):
             sub_size=self.sub_steps[-1],
         )
 
-        iterated_array_2d = iterated_array + array_higher_sub.in_2d_binned
+        iterated_array_2d = iterated_array + array_higher_sub.native_binned
 
-        iterated_array_1d = array_util.sub_array_1d_from(
-            mask=self.mask, sub_array_2d=iterated_array_2d, sub_size=1
+        iterated_array_1d = array_util.sub_array_2d_slim_from(
+            mask_2d=self.mask, sub_array_2d=iterated_array_2d, sub_size=1
         )
 
-        return arrays.Array(
-            array=iterated_array_1d, mask=self.mask.mask_sub_1, store_in_1d=True
+        return arrays.Array2D(
+            array=iterated_array_1d, mask=self.mask.mask_sub_1, store_slim=True
         )
 
     @staticmethod
@@ -607,7 +615,7 @@ class GridIterate(abstract_grid.AbstractGrid):
     ) -> msk.Mask2D:
         """
         Returns a fractional mask from a result array, where the fractional mask describes whether the evaluated
-            value in the result array is within the `GridIterate`'s specified fractional accuracy. The fractional mask thus
+            value in the result array is within the `Grid2DIterate`'s specified fractional accuracy. The fractional mask thus
             determines whether a pixel on the grid needs to be reevaluated at a higher level of sub-gridding to meet the
             specified fractional accuracy. If it must be re-evaluated, the fractional masks's entry is `False`.
 
@@ -617,14 +625,14 @@ class GridIterate(abstract_grid.AbstractGrid):
 
             Parameters
             ----------
-            grid_lower_sub_2d : arrays.Array
+            grid_lower_sub_2d : arrays.Array2D
                 The results computed by a function using a lower sub-grid size
-            grid_higher_sub_2d : grids.Array
+            grid_higher_sub_2d : grids.Array2D
                 The results computed by a function using a higher sub-grid size.
         """
 
         fractional_mask = msk.Mask2D.unmasked(
-            shape_2d=grid_lower_sub_2d.shape_2d,
+            shape_native=grid_lower_sub_2d.shape_native,
             pixel_scales=grid_lower_sub_2d.pixel_scales,
             invert=True,
         )
@@ -722,14 +730,14 @@ class GridIterate(abstract_grid.AbstractGrid):
             The function which is iterated over to compute a more precise evaluation.
         cls : object
             The class the function belongs to.
-        grid_lower_sub_2d : arrays.Array
+        grid_lower_sub_2d : arrays.Array2D
             The results computed by the function using a lower sub-grid size
         """
 
         if not np.any(grid_lower_sub_2d):
-            return grid_lower_sub_2d.in_1d
+            return grid_lower_sub_2d.slim
 
-        iterated_grid = np.zeros(shape=(self.shape_2d[0], self.shape_2d[1], 2))
+        iterated_grid = np.zeros(shape=(self.shape_native[0], self.shape_native[1], 2))
 
         fractional_mask_lower_sub = self.mask
 
@@ -752,12 +760,12 @@ class GridIterate(abstract_grid.AbstractGrid):
 
             if fractional_mask_higher_sub.is_all_true:
 
-                iterated_grid_1d = grid_util.sub_grid_1d_from(
+                iterated_grid_1d = grid_util.sub_grid_2d_slim_from(
                     mask=self.mask, sub_grid_2d=iterated_grid, sub_size=1
                 )
 
-                return grids.Grid(
-                    grid=iterated_grid_1d, mask=self.mask.mask_sub_1, store_in_1d=True
+                return grids.Grid2D(
+                    grid=iterated_grid_1d, mask=self.mask.mask_sub_1, store_slim=True
                 )
 
             grid_lower_sub_2d = grid_higher_sub
@@ -770,14 +778,14 @@ class GridIterate(abstract_grid.AbstractGrid):
             sub_size=self.sub_steps[-1],
         )
 
-        iterated_grid_2d = iterated_grid + grid_higher_sub.in_2d_binned
+        iterated_grid_2d = iterated_grid + grid_higher_sub.native_binned
 
-        iterated_grid_1d = grid_util.sub_grid_1d_from(
+        iterated_grid_1d = grid_util.sub_grid_2d_slim_from(
             mask=self.mask, sub_grid_2d=iterated_grid_2d, sub_size=1
         )
 
-        return grids.Grid(
-            grid=iterated_grid_1d, mask=self.mask.mask_sub_1, store_in_1d=True
+        return grids.Grid2D(
+            grid=iterated_grid_1d, mask=self.mask.mask_sub_1, store_slim=True
         )
 
     @staticmethod
@@ -822,7 +830,7 @@ class GridIterate(abstract_grid.AbstractGrid):
         result_sub_1_1d = func(cls, self.grid)
         result_sub_1_2d = self.grid.structure_from_result(
             result=result_sub_1_1d
-        ).in_2d_binned
+        ).native_binned
 
         if len(result_sub_1_2d.shape) == 2:
             return self.iterated_array_from_func(
