@@ -8,12 +8,14 @@ from autoarray.mask import mask_2d as msk
 from autoarray.util import grid_util, pixelization_util
 
 
-class GridRectangular(grids.Grid):
-    def __new__(cls, grid, shape_2d, pixel_scales, origin=(0.0, 0.0), *args, **kwargs):
+class Grid2DRectangular(grids.Grid2D):
+    def __new__(
+        cls, grid, shape_native, pixel_scales, origin=(0.0, 0.0), *args, **kwargs
+    ):
         """A grid of (y,x) coordinates which reprsent a rectangular grid of pixels which are used to form the pixel centres of adaptive pixelizations in the \
         *pixelizations* module.
 
-        A `GridRectangular` is ordered such pixels begin from the top-row of the mask and go rightwards and then \
+        A `Grid2DRectangular` is ordered such pixels begin from the top-row of the mask and go rightwards and then \
         downwards. Therefore, it is a ndarray of shape [total_pix_pixels, 2]. The first element of the ndarray \
         thus corresponds to the pixelization pixel index and second element the y or x arc -econd coordinates. For example:
 
@@ -25,12 +27,15 @@ class GridRectangular(grids.Grid):
         pix_grid : np.ndarray
             The grid of (y,x) scaled coordinates of every image-plane pixelization grid used for adaptive source \
             -plane pixelizations.
-        nearest_pixelization_1d_index_for_mask_1d_index : np.ndarray
+        nearest_pixelization_index_for_slim_index : np.ndarray
             A 1D array that maps every grid pixel to its nearest pixelization-grid pixel.
         """
 
         mask = msk.Mask2D.unmasked(
-            shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=1, origin=origin
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            sub_size=1,
+            origin=origin,
         )
 
         obj = super().__new__(cls=cls, grid=grid, mask=mask)
@@ -38,7 +43,7 @@ class GridRectangular(grids.Grid):
         (
             pixel_neighbors,
             pixel_neighbors_size,
-        ) = pixelization_util.rectangular_neighbors_from(shape_2d=shape_2d)
+        ) = pixelization_util.rectangular_neighbors_from(shape_native=shape_native)
         obj.pixel_neighbors = pixel_neighbors.astype("int")
         obj.pixel_neighbors_size = pixel_neighbors_size.astype("int")
         return obj
@@ -62,14 +67,14 @@ class GridRectangular(grids.Grid):
         super().__setstate__(state[0:-1])
 
     @classmethod
-    def overlay_grid(cls, shape_2d, grid, buffer=1e-8):
+    def overlay_grid(cls, shape_native, grid, buffer=1e-8):
         """The geometry of a rectangular grid.
 
         This is used to map grid of (y,x) scaled coordinates to the pixels on the rectangular grid.
 
         Parameters
         -----------
-        shape_2d : (int, int)
+        shape_native : (int, int)
             The dimensions of the rectangular grid of pixels (y_pixels, x_pixel)
         pixel_scales : (float, float)
             The pixel conversion scale of a pixel in the y and x directions.
@@ -89,33 +94,39 @@ class GridRectangular(grids.Grid):
         x_max = np.max(grid[:, 1]) + buffer
 
         pixel_scales = (
-            float((y_max - y_min) / shape_2d[0]),
-            float((x_max - x_min) / shape_2d[1]),
+            float((y_max - y_min) / shape_native[0]),
+            float((x_max - x_min) / shape_native[1]),
         )
 
         origin = ((y_max + y_min) / 2.0, (x_max + x_min) / 2.0)
 
-        grid_1d = grid_util.grid_1d_via_shape_2d_from(
-            shape_2d=shape_2d, pixel_scales=pixel_scales, sub_size=1, origin=origin
+        grid_slim = grid_util.grid_2d_slim_via_shape_native_from(
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            sub_size=1,
+            origin=origin,
         )
 
-        return GridRectangular(
-            grid=grid_1d, shape_2d=shape_2d, pixel_scales=pixel_scales, origin=origin
+        return Grid2DRectangular(
+            grid=grid_slim,
+            shape_native=shape_native,
+            pixel_scales=pixel_scales,
+            origin=origin,
         )
 
     @property
     def pixels(self):
-        return self.shape_2d[0] * self.shape_2d[1]
+        return self.shape_native[0] * self.shape_native[1]
 
     @property
-    def shape_2d_scaled(self):
+    def shape_native_scaled(self):
         return (
-            (self.shape_2d[0] * self.pixel_scales[0]),
-            (self.shape_2d[1] * self.pixel_scales[1]),
+            (self.shape_native[0] * self.pixel_scales[0]),
+            (self.shape_native[1] * self.pixel_scales[1]),
         )
 
 
-class GridVoronoi(np.ndarray):
+class Grid2DVoronoi(np.ndarray):
     """
     Returns the geometry of the Voronoi pixelization, by alligning it with the outer-most coordinates on a \
     grid plus a small buffer.
@@ -137,12 +148,12 @@ class GridVoronoi(np.ndarray):
     """
 
     def __new__(
-        cls, grid, nearest_pixelization_1d_index_for_mask_1d_index=None, *args, **kwargs
+        cls, grid, nearest_pixelization_index_for_slim_index=None, *args, **kwargs
     ):
         """A pixelization-grid of (y,x) coordinates which are used to form the pixel centres of adaptive pixelizations in the \
         *pixelizations* module.
 
-        A `GridRectangular` is ordered such pixels begin from the top-row of the mask and go rightwards and then \
+        A `Grid2DRectangular` is ordered such pixels begin from the top-row of the mask and go rightwards and then \
         downwards. Therefore, it is a ndarray of shape [total_pix_pixels, 2]. The first element of the ndarray \
         thus corresponds to the pixelization pixel index and second element the y or x arc -econd coordinates. For example:
 
@@ -154,7 +165,7 @@ class GridVoronoi(np.ndarray):
         pix_grid : np.ndarray
             The grid of (y,x) scaled coordinates of every image-plane pixelization grid used for adaptive source \
             -plane pixelizations.
-        nearest_pixelization_1d_index_for_mask_1d_index : np.ndarray
+        nearest_pixelization_index_for_slim_index : np.ndarray
             A 1D array that maps every grid pixel to its nearest pixelization-grid pixel.
         """
 
@@ -162,12 +173,10 @@ class GridVoronoi(np.ndarray):
             grid = np.asarray(grid)
 
         obj = grid.view(cls)
-        obj.nearest_pixelization_1d_index_for_mask_1d_index = (
-            nearest_pixelization_1d_index_for_mask_1d_index
+        obj.nearest_pixelization_index_for_slim_index = (
+            nearest_pixelization_index_for_slim_index
         )
 
-        obj.pixels = grid.shape[0]
-
         try:
             obj.voronoi = scipy.spatial.Voronoi(
                 np.asarray([grid[:, 1], grid[:, 0]]).T, qhull_options="Qbb Qc Qx Qm"
@@ -184,25 +193,31 @@ class GridVoronoi(np.ndarray):
 
         obj.pixel_neighbors = pixel_neighbors.astype("int")
         obj.pixel_neighbors_size = pixel_neighbors_size.astype("int")
-        obj.nearest_pixelization_1d_index_for_mask_1d_index = (
-            nearest_pixelization_1d_index_for_mask_1d_index
+        obj.nearest_pixelization_index_for_slim_index = (
+            nearest_pixelization_index_for_slim_index
         )
 
         return obj
 
     def __array_finalize__(self, obj):
 
+        if hasattr(obj, "voronoi"):
+            self.voronoi = obj.voronoi
+
         if hasattr(obj, "pixel_neighbors"):
             self.pixel_neighbors = obj.pixel_neighbors
 
         if hasattr(obj, "pixel_neighbors_size"):
             self.pixel_neighbors_size = obj.pixel_neighbors_size
 
-        if hasattr(obj, "nearest_pixelization_1d_index_for_mask_1d_index"):
-            self.nearest_pixelization_1d_index_for_mask_1d_index = (
-                obj.nearest_pixelization_1d_index_for_mask_1d_index
+        if hasattr(obj, "nearest_pixelization_index_for_slim_index"):
+            self.nearest_pixelization_index_for_slim_index = (
+                obj.nearest_pixelization_index_for_slim_index
             )
 
+        if hasattr(obj, "_sub_border_flat_indexes"):
+            self._sub_border_flat_indexes = obj._sub_border_flat_indexes
+
     def __reduce__(self):
         # Get the parent's __reduce__ tuple
         pickled_state = super().__reduce__()
@@ -221,24 +236,40 @@ class GridVoronoi(np.ndarray):
             setattr(self, key, value)
         super().__setstate__(state[0:-1])
 
+    @property
+    def origin(self):
+        return 0.0, 0.0
+
+    @property
+    def pixels(self):
+        return self.shape[0]
+
+    @property
+    def sub_border_grid(self):
+        """The (y,x) grid of all sub-pixels which are at the border of the mask.
+
+        This is NOT all sub-pixels which are in mask pixels at the mask's border, but specifically the sub-pixels
+        within these border pixels which are at the extreme edge of the border."""
+        return self[self._sub_border_flat_indexes]
+
     @classmethod
-    def manual_1d(cls, grid):
-        return GridVoronoi(grid=grid)
+    def manual_slim(cls, grid):
+        return Grid2DVoronoi(grid=grid)
 
     @classmethod
     def from_grid_and_unmasked_2d_grid_shape(cls, unmasked_sparse_shape, grid):
 
-        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.Grid2DSparse.from_grid_and_unmasked_2d_grid_shape(
             unmasked_sparse_shape=unmasked_sparse_shape, grid=grid
         )
 
-        return GridVoronoi(
+        return Grid2DVoronoi(
             grid=sparse_grid.sparse,
-            nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=sparse_grid.sparse_index_for_slim_index,
         )
 
     @property
-    def shape_2d_scaled(self):
+    def shape_native_scaled(self):
         return (
             np.amax(self[:, 0]) - np.amin(self[:, 0]),
             np.amax(self[:, 1]) - np.amin(self[:, 1]),
