@@ -12,14 +12,14 @@ class TestFitImaging:
             mask=[[False, False], [False, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Array.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
-        noise_map = aa.Array.manual_mask(array=[2.0, 2.0, 2.0, 2.0], mask=mask)
+        data = aa.Array2D.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
+        noise_map = aa.Array2D.manual_mask(array=[2.0, 2.0, 2.0, 2.0], mask=mask)
 
         imaging = aa.Imaging(image=data, noise_map=noise_map)
 
         masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_image = aa.Array.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
+        model_image = aa.Array2D.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
 
         fit = aa.FitImaging(
             masked_imaging=masked_imaging,
@@ -29,32 +29,32 @@ class TestFitImaging:
 
         assert (fit.mask == np.array([[False, False], [False, False]])).all()
 
-        assert (fit.image.in_1d == np.array([1.0, 2.0, 3.0, 4.0])).all()
-        assert (fit.image.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
+        assert (fit.image.slim == np.array([1.0, 2.0, 3.0, 4.0])).all()
+        assert (fit.image.native == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
 
-        assert (fit.noise_map.in_1d == np.array([2.0, 2.0, 2.0, 2.0])).all()
-        assert (fit.noise_map.in_2d == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
+        assert (fit.noise_map.slim == np.array([2.0, 2.0, 2.0, 2.0])).all()
+        assert (fit.noise_map.native == np.array([[2.0, 2.0], [2.0, 2.0]])).all()
 
-        assert (fit.signal_to_noise_map.in_1d == np.array([0.5, 1.0, 1.5, 2.0])).all()
+        assert (fit.signal_to_noise_map.slim == np.array([0.5, 1.0, 1.5, 2.0])).all()
         assert (
-            fit.signal_to_noise_map.in_2d == np.array([[0.5, 1.0], [1.5, 2.0]])
+            fit.signal_to_noise_map.native == np.array([[0.5, 1.0], [1.5, 2.0]])
         ).all()
 
-        assert (fit.model_image.in_1d == np.array([1.0, 2.0, 3.0, 4.0])).all()
-        assert (fit.model_image.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
+        assert (fit.model_image.slim == np.array([1.0, 2.0, 3.0, 4.0])).all()
+        assert (fit.model_image.native == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
 
-        assert (fit.residual_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])).all()
-        assert (fit.residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
+        assert (fit.residual_map.slim == np.array([0.0, 0.0, 0.0, 0.0])).all()
+        assert (fit.residual_map.native == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
 
         assert (
-            fit.normalized_residual_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])
+            fit.normalized_residual_map.slim == np.array([0.0, 0.0, 0.0, 0.0])
         ).all()
         assert (
-            fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])
+            fit.normalized_residual_map.native == np.array([[0.0, 0.0], [0.0, 0.0]])
         ).all()
 
-        assert (fit.chi_squared_map.in_1d == np.array([0.0, 0.0, 0.0, 0.0])).all()
-        assert (fit.chi_squared_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
+        assert (fit.chi_squared_map.slim == np.array([0.0, 0.0, 0.0, 0.0])).all()
+        assert (fit.chi_squared_map.native == np.array([[0.0, 0.0], [0.0, 0.0]])).all()
 
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
@@ -69,14 +69,14 @@ class TestFitImaging:
             mask=[[False, False], [True, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Array.manual_mask(array=[1.0, 2.0, 4.0], mask=mask)
-        noise_map = aa.Array.manual_mask(array=[2.0, 2.0, 2.0], mask=mask)
+        data = aa.Array2D.manual_mask(array=[1.0, 2.0, 4.0], mask=mask)
+        noise_map = aa.Array2D.manual_mask(array=[2.0, 2.0, 2.0], mask=mask)
 
         imaging = aa.Imaging(image=data, noise_map=noise_map)
 
         masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_image = aa.Array.manual_mask(array=[1.0, 2.0, 3.0], mask=mask)
+        model_image = aa.Array2D.manual_mask(array=[1.0, 2.0, 3.0], mask=mask)
 
         fit = aa.FitImaging(
             masked_imaging=masked_imaging,
@@ -86,30 +86,30 @@ class TestFitImaging:
 
         assert (fit.mask == np.array([[False, False], [True, False]])).all()
 
-        assert (fit.image.in_1d == np.array([1.0, 2.0, 4.0])).all()
-        assert (fit.image.in_2d == np.array([[1.0, 2.0], [0.0, 4.0]])).all()
+        assert (fit.image.slim == np.array([1.0, 2.0, 4.0])).all()
+        assert (fit.image.native == np.array([[1.0, 2.0], [0.0, 4.0]])).all()
 
-        assert (fit.noise_map.in_1d == np.array([2.0, 2.0, 2.0])).all()
-        assert (fit.noise_map.in_2d == np.array([[2.0, 2.0], [0.0, 2.0]])).all()
+        assert (fit.noise_map.slim == np.array([2.0, 2.0, 2.0])).all()
+        assert (fit.noise_map.native == np.array([[2.0, 2.0], [0.0, 2.0]])).all()
 
-        assert (fit.signal_to_noise_map.in_1d == np.array([0.5, 1.0, 2.0])).all()
+        assert (fit.signal_to_noise_map.slim == np.array([0.5, 1.0, 2.0])).all()
         assert (
-            fit.signal_to_noise_map.in_2d == np.array([[0.5, 1.0], [0.0, 2.0]])
+            fit.signal_to_noise_map.native == np.array([[0.5, 1.0], [0.0, 2.0]])
         ).all()
 
-        assert (fit.model_image.in_1d == np.array([1.0, 2.0, 3.0])).all()
-        assert (fit.model_image.in_2d == np.array([[1.0, 2.0], [0.0, 3.0]])).all()
+        assert (fit.model_image.slim == np.array([1.0, 2.0, 3.0])).all()
+        assert (fit.model_image.native == np.array([[1.0, 2.0], [0.0, 3.0]])).all()
 
-        assert (fit.residual_map.in_1d == np.array([0.0, 0.0, 1.0])).all()
-        assert (fit.residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 1.0]])).all()
+        assert (fit.residual_map.slim == np.array([0.0, 0.0, 1.0])).all()
+        assert (fit.residual_map.native == np.array([[0.0, 0.0], [0.0, 1.0]])).all()
 
-        assert (fit.normalized_residual_map.in_1d == np.array([0.0, 0.0, 0.5])).all()
+        assert (fit.normalized_residual_map.slim == np.array([0.0, 0.0, 0.5])).all()
         assert (
-            fit.normalized_residual_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.5]])
+            fit.normalized_residual_map.native == np.array([[0.0, 0.0], [0.0, 0.5]])
         ).all()
 
-        assert (fit.chi_squared_map.in_1d == np.array([0.0, 0.0, 0.25])).all()
-        assert (fit.chi_squared_map.in_2d == np.array([[0.0, 0.0], [0.0, 0.25]])).all()
+        assert (fit.chi_squared_map.slim == np.array([0.0, 0.0, 0.25])).all()
+        assert (fit.chi_squared_map.native == np.array([[0.0, 0.0], [0.0, 0.25]])).all()
 
         assert fit.chi_squared == 0.25
         assert fit.reduced_chi_squared == 0.25 / 3.0
@@ -124,14 +124,14 @@ class TestFitImaging:
             mask=[[False, False], [False, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Array.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
-        noise_map = aa.Array.manual_mask(array=[2.0, 2.0, 2.0, 2.0], mask=mask)
+        data = aa.Array2D.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
+        noise_map = aa.Array2D.manual_mask(array=[2.0, 2.0, 2.0, 2.0], mask=mask)
 
         imaging = aa.Imaging(image=data, noise_map=noise_map)
 
         masked_imaging = aa.MaskedImaging(imaging=imaging, mask=mask)
 
-        model_image = aa.Array.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
+        model_image = aa.Array2D.manual_mask(array=[1.0, 2.0, 3.0, 4.0], mask=mask)
 
         inversion = mock.MockFitInversion(
             regularization_term=2.0,
@@ -171,8 +171,8 @@ class TestFitInterferometer:
             mask=[[False, False], [False, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Visibilities.manual_1d(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
-        noise_map = aa.VisibilitiesNoiseMap.manual_1d(
+        data = aa.Visibilities.manual_slim(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
+        noise_map = aa.VisibilitiesNoiseMap.manual_slim(
             visibilities=[2.0 + 2.0j, 2.0 + 2.0j]
         )
 
@@ -186,7 +186,7 @@ class TestFitInterferometer:
             real_space_mask=real_space_mask,
         )
 
-        model_visibilities = aa.Visibilities.manual_1d(
+        model_visibilities = aa.Visibilities.manual_slim(
             visibilities=[1.0 + 2.0j, 3.0 + 4.0j]
         )
 
@@ -200,25 +200,23 @@ class TestFitInterferometer:
             fit.visibilities_mask == np.array([[False, False], [False, False]])
         ).all()
 
-        assert (fit.visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
+        assert (fit.visibilities.slim == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
 
-        assert (fit.noise_map.in_1d == np.array([2.0 + 2.0j, 2.0 + 2.0j])).all()
+        assert (fit.noise_map.slim == np.array([2.0 + 2.0j, 2.0 + 2.0j])).all()
 
         assert (
-            fit.signal_to_noise_map.in_1d == np.array([0.5 + 1.0j, 1.5 + 2.0j])
+            fit.signal_to_noise_map.slim == np.array([0.5 + 1.0j, 1.5 + 2.0j])
         ).all()
 
+        assert (fit.model_visibilities.slim == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
+
+        assert (fit.residual_map.slim == np.array([0.0 + 0.0j, 0.0 + 0.0j])).all()
+
         assert (
-            fit.model_visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])
+            fit.normalized_residual_map.slim == np.array([0.0 + 0.0j, 0.0 + 0.0j])
         ).all()
 
-        assert (fit.residual_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.0j])).all()
-
-        assert (
-            fit.normalized_residual_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.0j])
-        ).all()
-
-        assert (fit.chi_squared_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.0j])).all()
+        assert (fit.chi_squared_map.slim == np.array([0.0 + 0.0j, 0.0 + 0.0j])).all()
 
         assert fit.chi_squared == 0.0
         assert fit.reduced_chi_squared == 0.0
@@ -235,8 +233,8 @@ class TestFitInterferometer:
             mask=[[False, False], [False, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Visibilities.manual_1d(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
-        noise_map = aa.VisibilitiesNoiseMap.manual_1d(
+        data = aa.Visibilities.manual_slim(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
+        noise_map = aa.VisibilitiesNoiseMap.manual_slim(
             visibilities=[2.0 + 2.0j, 2.0 + 2.0j]
         )
 
@@ -250,7 +248,7 @@ class TestFitInterferometer:
             real_space_mask=real_space_mask,
         )
 
-        model_visibilities = aa.Visibilities.manual_1d(
+        model_visibilities = aa.Visibilities.manual_slim(
             visibilities=[1.0 + 2.0j, 3.0 + 3.0j]
         )
 
@@ -264,25 +262,23 @@ class TestFitInterferometer:
             fit.visibilities_mask == np.array([[False, False], [False, False]])
         ).all()
 
-        assert (fit.visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
+        assert (fit.visibilities.slim == np.array([1.0 + 2.0j, 3.0 + 4.0j])).all()
 
-        assert (fit.noise_map.in_1d == np.array([2.0 + 2.0j, 2.0 + 2.0j])).all()
+        assert (fit.noise_map.slim == np.array([2.0 + 2.0j, 2.0 + 2.0j])).all()
 
         assert (
-            fit.signal_to_noise_map.in_1d == np.array([0.5 + 1.0j, 1.5 + 2.0j])
+            fit.signal_to_noise_map.slim == np.array([0.5 + 1.0j, 1.5 + 2.0j])
         ).all()
 
+        assert (fit.model_visibilities.slim == np.array([1.0 + 2.0j, 3.0 + 3.0j])).all()
+
+        assert (fit.residual_map.slim == np.array([0.0 + 0.0j, 0.0 + 1.0j])).all()
+
         assert (
-            fit.model_visibilities.in_1d == np.array([1.0 + 2.0j, 3.0 + 3.0j])
+            fit.normalized_residual_map.slim == np.array([0.0 + 0.0j, 0.0 + 0.5j])
         ).all()
 
-        assert (fit.residual_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 1.0j])).all()
-
-        assert (
-            fit.normalized_residual_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.5j])
-        ).all()
-
-        assert (fit.chi_squared_map.in_1d == np.array([0.0 + 0.0j, 0.0 + 0.25j])).all()
+        assert (fit.chi_squared_map.slim == np.array([0.0 + 0.0j, 0.0 + 0.25j])).all()
 
         assert fit.chi_squared == 0.25
         assert fit.reduced_chi_squared == 0.25 / 2.0
@@ -299,8 +295,8 @@ class TestFitInterferometer:
             mask=[[False, False], [False, False]], sub_size=1, pixel_scales=(1.0, 1.0)
         )
 
-        data = aa.Visibilities.manual_1d(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
-        noise_map = aa.VisibilitiesNoiseMap.manual_1d(
+        data = aa.Visibilities.manual_slim(visibilities=[1.0 + 2.0j, 3.0 + 4.0j])
+        noise_map = aa.VisibilitiesNoiseMap.manual_slim(
             visibilities=[2.0 + 2.0j, 2.0 + 2.0j]
         )
 
@@ -314,7 +310,7 @@ class TestFitInterferometer:
             real_space_mask=real_space_mask,
         )
 
-        model_visibilities = aa.Visibilities.manual_1d(
+        model_visibilities = aa.Visibilities.manual_slim(
             visibilities=[1.0 + 2.0j, 3.0 + 4.0j]
         )
 
