@@ -24,7 +24,7 @@ class TestRectangular:
 
         # Source-plane comprises 5 grid, so 5 masked_image pixels traced to the pix-plane.
 
-        grid = aa.Grid.manual_mask(
+        grid = aa.Grid2D.manual_mask(
             grid=[[1.0, -1.0], [1.0, 1.0], [0.0, 0.0], [-1.0, -1.0], [-1.0, 1.0]],
             mask=mask,
         )
@@ -41,9 +41,11 @@ class TestRectangular:
             hyper_image=np.ones((2, 2)),
         )
 
-        assert mapper.is_image_plane_pixelization == False
-        assert mapper.grid.shape_2d_scaled == pytest.approx((2.0, 2.0), 1.0e-4)
-        assert mapper.grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
+        assert mapper.data_pixelization_grid == None
+        assert mapper.source_grid_slim.shape_native_scaled == pytest.approx(
+            (2.0, 2.0), 1.0e-4
+        )
+        assert mapper.source_grid_slim.origin == pytest.approx((0.0, 0.0), 1.0e-4)
 
         assert (
             mapper.mapping_matrix
@@ -57,7 +59,7 @@ class TestRectangular:
                 ]
             )
         ).all()
-        assert mapper.shape_2d == (3, 3)
+        assert mapper.shape_native == (3, 3)
         assert (mapper.hyper_image == np.ones((2, 2))).all()
 
         reg = aa.reg.Constant(coefficient=1.0)
@@ -80,9 +82,9 @@ class TestRectangular:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -117,7 +119,7 @@ class TestRectangular:
 
         # There is no sub-grid, so our grid are just the masked_image grid (note the NumPy weighted_data structure
         # ensures this has no sub-gridding)
-        grid = aa.Grid.manual_mask(
+        grid = aa.Grid2D.manual_mask(
             grid=[
                 [0.9, -0.9],
                 [1.0, -1.0],
@@ -146,11 +148,13 @@ class TestRectangular:
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == False
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert mapper.data_pixelization_grid == None
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.2, 2.2), 1.0e-4
         )
-        assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
+        assert mapper.source_pixelization_grid.origin == pytest.approx(
+            (0.0, 0.0), 1.0e-4
+        )
 
         assert (
             mapper.mapping_matrix
@@ -174,7 +178,7 @@ class TestRectangular:
                 ]
             )
         ).all()
-        assert mapper.shape_2d == (3, 3)
+        assert mapper.shape_native == (3, 3)
 
         reg = aa.reg.Constant(coefficient=1.0)
         regularization_matrix = reg.regularization_matrix_from_mapper(mapper=mapper)
@@ -196,9 +200,9 @@ class TestRectangular:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -237,7 +241,7 @@ class TestRectangular:
         # The grid below is unphysical in that the (0.0, 0.0) terms on the end of each sub-grid probably couldn't
         # happen for a real lens calculation. This is to make a mapping_matrix matrix which explicitly tests the
         # sub-grid.
-        grid = aa.Grid.manual_mask(
+        grid = aa.Grid2D.manual_mask(
             grid=[
                 [1.0, -1.0],
                 [1.0, -1.0],
@@ -271,11 +275,13 @@ class TestRectangular:
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == False
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert mapper.data_pixelization_grid == None
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.0, 2.0), 1.0e-4
         )
-        assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
+        assert mapper.source_pixelization_grid.origin == pytest.approx(
+            (0.0, 0.0), 1.0e-4
+        )
 
         assert (
             mapper.mapping_matrix
@@ -289,7 +295,7 @@ class TestRectangular:
                 ]
             )
         ).all()
-        assert mapper.shape_2d == (3, 3)
+        assert mapper.shape_native == (3, 3)
 
         reg = aa.reg.Constant(coefficient=1.0)
         regularization_matrix = reg.regularization_matrix_from_mapper(mapper=mapper)
@@ -311,9 +317,9 @@ class TestRectangular:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -346,7 +352,7 @@ class TestRectangular:
             sub_size=1,
         )
 
-        grid = aa.Grid.manual_mask(
+        grid = aa.Grid2D.manual_mask(
             grid=[[1.0, 1.0], [1.0, 1.0], [1.0, 1.0], [1.0, 1.0], [-1.0, -1.0]],
             mask=mask,
         )
@@ -359,11 +365,13 @@ class TestRectangular:
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == False
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert mapper.data_pixelization_grid == None
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.0, 2.0), 1.0e-4
         )
-        assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
+        assert mapper.source_pixelization_grid.origin == pytest.approx(
+            (0.0, 0.0), 1.0e-4
+        )
 
         assert (
             mapper.mapping_matrix
@@ -377,7 +385,7 @@ class TestRectangular:
                 ]
             )
         ).all()
-        assert mapper.shape_2d == (3, 3)
+        assert mapper.shape_native == (3, 3)
 
         reg = aa.reg.Constant(coefficient=1.0)
         regularization_matrix = reg.regularization_matrix_from_mapper(mapper=mapper)
@@ -399,9 +407,9 @@ class TestRectangular:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -423,10 +431,10 @@ class TestRectangular:
         visibilities_mask = np.full(fill_value=False, shape=(7,))
 
         real_space_mask = aa.Mask2D.unmasked(
-            shape_2d=(7, 7), pixel_scales=0.1, sub_size=1
+            shape_native=(7, 7), pixel_scales=0.1, sub_size=1
         )
 
-        grid = aa.Grid.from_mask(mask=real_space_mask)
+        grid = aa.Grid2D.from_mask(mask=real_space_mask)
 
         pix = aa.pix.Rectangular(shape=(7, 7))
 
@@ -438,7 +446,7 @@ class TestRectangular:
 
         reg = aa.reg.Constant(coefficient=0.0)
 
-        visibilities = aa.Visibilities.manual_1d(
+        visibilities = aa.Visibilities.manual_slim(
             visibilities=[
                 1.0 + 0.0j,
                 1.0 + 0.0j,
@@ -449,7 +457,7 @@ class TestRectangular:
                 1.0 + 0.0j,
             ]
         )
-        noise_map = aa.VisibilitiesNoiseMap.ones(shape_1d=(7,))
+        noise_map = aa.VisibilitiesNoiseMap.ones(shape_slim=(7,))
         uv_wavelengths = np.ones(shape=(7, 2))
 
         interferometer = aa.Interferometer(
@@ -482,10 +490,10 @@ class TestRectangular:
         visibilities_mask = np.full(fill_value=False, shape=(7,))
 
         real_space_mask = aa.Mask2D.unmasked(
-            shape_2d=(7, 7), pixel_scales=0.1, sub_size=1
+            shape_native=(7, 7), pixel_scales=0.1, sub_size=1
         )
 
-        grid = aa.Grid.from_mask(mask=real_space_mask)
+        grid = aa.Grid2D.from_mask(mask=real_space_mask)
 
         pix = aa.pix.Rectangular(shape=(7, 7))
 
@@ -497,7 +505,7 @@ class TestRectangular:
 
         reg = aa.reg.Constant(coefficient=0.0)
 
-        visibilities = aa.Visibilities.manual_1d(
+        visibilities = aa.Visibilities.manual_slim(
             visibilities=[
                 1.0 + 0.0j,
                 1.0 + 0.0j,
@@ -508,7 +516,7 @@ class TestRectangular:
                 1.0 + 0.0j,
             ]
         )
-        noise_map = aa.VisibilitiesNoiseMap.ones(shape_1d=(7,))
+        noise_map = aa.VisibilitiesNoiseMap.ones(shape_slim=(7,))
         uv_wavelengths = np.ones(shape=(7, 2))
 
         interferometer = aa.Interferometer(
@@ -571,30 +579,33 @@ class TestVoronoiMagnification:
             ]
         )
 
-        grid = aa.Grid.manual_mask(grid=grid, mask=mask)
+        grid = aa.Grid2D.manual_mask(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.Grid2DSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
-        pixelization_grid = aa.GridVoronoi(
+        pixelization_grid = aa.Grid2DVoronoi(
             grid=sparse_grid.sparse,
-            nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=sparse_grid.sparse_index_for_slim_index,
         )
 
+        sparse_image_plane_grid = aa.Grid2DIrregular(grid=[(0.0, 0.0)])
+
         mapper = pix.mapper_from_grid_and_sparse_grid(
             grid=grid,
             sparse_grid=pixelization_grid,
             settings=aa.SettingsPixelization(use_border=False),
+            sparse_image_plane_grid=sparse_image_plane_grid,
             hyper_image=np.ones((2, 2)),
         )
 
-        assert mapper.is_image_plane_pixelization == True
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert (mapper.data_pixelization_grid == sparse_image_plane_grid).all()
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.0, 2.0), 1.0e-4
         )
-        assert (mapper.pixelization_grid == sparse_grid.sparse).all()
+        assert (mapper.source_pixelization_grid == sparse_grid.sparse).all()
         #     assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
         assert (mapper.hyper_image == np.ones((2, 2))).all()
 
@@ -637,9 +648,9 @@ class TestVoronoiMagnification:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -672,29 +683,27 @@ class TestVoronoiMagnification:
 
         grid = np.array([[1.0, 0.0], [0.0, -1.0], [0.0, 0.0], [0.0, 1.0], [-1.0, 0.0]])
 
-        grid = aa.Grid.manual_mask(grid=grid, mask=mask)
+        grid = aa.Grid2D.manual_mask(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.Grid2DSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
-        pixelization_grid = aa.GridVoronoi(
+        pixelization_grid = aa.Grid2DVoronoi(
             grid=sparse_grid.sparse,
-            nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=sparse_grid.sparse_index_for_slim_index,
         )
-
         mapper = pix.mapper_from_grid_and_sparse_grid(
             grid=grid,
             sparse_grid=pixelization_grid,
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == True
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.0, 2.0), 1.0e-4
         )
-        assert (mapper.pixelization_grid == sparse_grid.sparse).all()
+        assert (mapper.source_pixelization_grid == sparse_grid.sparse).all()
         #   assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.0), 1.0e-4)
 
         assert isinstance(mapper, mappers.MapperVoronoi)
@@ -728,9 +737,9 @@ class TestVoronoiMagnification:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -786,16 +795,16 @@ class TestVoronoiMagnification:
             ]
         )
 
-        grid = aa.Grid.manual_mask(grid=grid, mask=mask)
+        grid = aa.Grid2D.manual_mask(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.Grid2DSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
-        pixelization_grid = aa.GridVoronoi(
+        pixelization_grid = aa.Grid2DVoronoi(
             grid=sparse_grid.sparse,
-            nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=sparse_grid.sparse_index_for_slim_index,
         )
 
         mapper = pix.mapper_from_grid_and_sparse_grid(
@@ -804,9 +813,10 @@ class TestVoronoiMagnification:
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == True
-        assert mapper.grid.shape_2d_scaled == pytest.approx((2.02, 2.01), 1.0e-4)
-        assert (mapper.pixelization_grid == sparse_grid.sparse).all()
+        assert mapper.source_grid_slim.shape_native_scaled == pytest.approx(
+            (2.02, 2.01), 1.0e-4
+        )
+        assert (mapper.source_pixelization_grid == sparse_grid.sparse).all()
         #    assert mapper.pixelization_grid.origin == pytest.approx((0.0, 0.005), 1.0e-4)
 
         assert isinstance(mapper, mappers.MapperVoronoi)
@@ -840,9 +850,9 @@ class TestVoronoiMagnification:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(5, 5), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(5, 5), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -877,16 +887,16 @@ class TestVoronoiMagnification:
 
         grid = np.array([[2.0, 1.0], [1.0, 0.0], [1.0, 1.0], [1.0, 2.0], [0.0, 1.0]])
 
-        grid = aa.Grid.manual_mask(grid=grid, mask=mask)
+        grid = aa.Grid2D.manual_mask(grid=grid, mask=mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(3, 3))
-        sparse_grid = grids.GridSparse.from_grid_and_unmasked_2d_grid_shape(
+        sparse_grid = grids.Grid2DSparse.from_grid_and_unmasked_2d_grid_shape(
             grid=grid, unmasked_sparse_shape=pix.shape
         )
 
-        pixelization_grid = aa.GridVoronoi(
+        pixelization_grid = aa.Grid2DVoronoi(
             grid=sparse_grid.sparse,
-            nearest_pixelization_1d_index_for_mask_1d_index=sparse_grid.sparse_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=sparse_grid.sparse_index_for_slim_index,
         )
 
         mapper = pix.mapper_from_grid_and_sparse_grid(
@@ -895,11 +905,10 @@ class TestVoronoiMagnification:
             settings=aa.SettingsPixelization(use_border=False),
         )
 
-        assert mapper.is_image_plane_pixelization == True
-        assert mapper.pixelization_grid.shape_2d_scaled == pytest.approx(
+        assert mapper.source_pixelization_grid.shape_native_scaled == pytest.approx(
             (2.0, 2.0), 1.0e-4
         )
-        assert (mapper.pixelization_grid == sparse_grid.sparse).all()
+        assert (mapper.source_pixelization_grid == sparse_grid.sparse).all()
         #   assert mapper.pixelization_grid.origin == pytest.approx((1.0, 1.0), 1.0e-4)
 
         assert isinstance(mapper, mappers.MapperVoronoi)
@@ -933,9 +942,9 @@ class TestVoronoiMagnification:
             )
         ).all()
 
-        image = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        noise_map = aa.Array.ones(shape_2d=(7, 7), pixel_scales=1.0)
-        psf = aa.Kernel.no_blur(pixel_scales=1.0)
+        image = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        noise_map = aa.Array2D.ones(shape_native=(7, 7), pixel_scales=1.0)
+        psf = aa.Kernel2D.no_blur(pixel_scales=1.0)
 
         imaging = aa.Imaging(image=image, noise_map=noise_map, psf=psf)
 
@@ -957,10 +966,10 @@ class TestVoronoiMagnification:
         visibilities_mask = np.full(fill_value=False, shape=(7,))
 
         real_space_mask = aa.Mask2D.unmasked(
-            shape_2d=(7, 7), pixel_scales=0.1, sub_size=1
+            shape_native=(7, 7), pixel_scales=0.1, sub_size=1
         )
 
-        grid = aa.Grid.from_mask(mask=real_space_mask)
+        grid = aa.Grid2D.from_mask(mask=real_space_mask)
 
         pix = aa.pix.VoronoiMagnification(shape=(7, 7))
 
@@ -974,7 +983,7 @@ class TestVoronoiMagnification:
 
         reg = aa.reg.Constant(coefficient=0.0)
 
-        visibilities = aa.Visibilities.manual_1d(
+        visibilities = aa.Visibilities.manual_slim(
             visibilities=[
                 1.0 + 0.0j,
                 1.0 + 0.0j,
@@ -985,7 +994,7 @@ class TestVoronoiMagnification:
                 1.0 + 0.0j,
             ]
         )
-        noise_map = aa.VisibilitiesNoiseMap.ones(shape_1d=(7,))
+        noise_map = aa.VisibilitiesNoiseMap.ones(shape_slim=(7,))
         uv_wavelengths = np.ones(shape=(7, 2))
 
         interferometer = aa.Interferometer(
