@@ -30,7 +30,7 @@ def grid_to_pixel_pixels_via_nearest_neighbour(grid, pixel_centers):
 
 
 class TestRectangularMapper:
-    def test__sub_to_pix__variuos_grids__1_coordinate_per_square_pixel__in_centre_of_pixels(
+    def test__sub_to_pix__various_grids__1_coordinate_per_square_pixel__in_centre_of_pixels(
         self,
     ):
         #   _ _ _
@@ -38,7 +38,7 @@ class TestRectangularMapper:
         #  I_I_I_I Boundaries for pixels x = 1 and y = 1 - (1/3) to (1/3)
         #  I_I_I_I Boundaries for pixels x = 2 and y = 2 - (1/3)" to 1.0"
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -51,21 +51,25 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular(
-            grid=np.ones((2, 2)), shape_2d=(3, 3), pixel_scales=(1.0, 1.0)
+        pixelization_grid = aa.Grid2DRectangular(
+            grid=np.ones((2, 2)), shape_native=(3, 3), pixel_scales=(1.0, 1.0)
         )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        print(mapper.all_sub_slim_indexes_for_pixelization_index)
+
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -82,7 +86,7 @@ class TestRectangularMapper:
         #  I_I_I_I Boundaries for pixels x = 1 and y = 1 - (1/3) to (1/3)
         #  I_I_I_I Boundaries for pixels x = 2 and y = 2 - (1/3)" to 1.0"
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -95,19 +99,23 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -125,7 +133,7 @@ class TestRectangularMapper:
         # -(1/3) to (1/3) I_I_I_I
         #  (1/3) to 1.0   I_I_I_I
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [0.0, 0.0],
@@ -138,19 +146,23 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 4, 2, 4, 4, 4, 6, 4, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [],
             [2],
@@ -178,7 +190,7 @@ class TestRectangularMapper:
         # Bounadries for row pixel 2  0.0 to 0.5
         # Bounadries for row pixel 3  0.5 to 1.0
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -188,19 +200,23 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 2),
+            shape_native=(3, 2),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(4, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(4, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 3, 8, 11])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -229,7 +245,7 @@ class TestRectangularMapper:
         # Bounadries for column pixel 2  0.0 to 0.5
         # Bounadries for column pixel 3  0.5 to 1.0
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [1.0, -0.49],
@@ -239,19 +255,23 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(2, 3),
+            shape_native=(2, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 4), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 4), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 6, 9, 11])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -274,22 +294,25 @@ class TestRectangularMapper:
         #  I_I_I_I Boundaries for pixels x = 1 and y = 1 -0.5 to 0.5
         #  I_I_I_I Boundaries for pixels x = 2 and y = 2  0.5 to 1.5
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.5, -1.5], [1.0, 0.0], [1.0, 0.6], [-1.4, 0.0], [-1.5, 1.5]],
             pixel_scales=1.0,
-            shape_2d=(5, 1),
+            shape_native=(5, 1),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == np.array([0, 1, 2, 7, 8])
+            mapper.pixelization_index_for_sub_slim_index == np.array([0, 1, 2, 7, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -309,22 +332,25 @@ class TestRectangularMapper:
         #  I_I_I_I Boundaries for pixels x = 1 and y = 1 -0.5 to 0.5
         #  I_I_I_I Boundaries for pixels x = 2 and y = 2  0.5 to 1.5
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [0.32, 0.51], [-1.0, 1.5]],
             pixel_scales=1.0,
-            shape_2d=(5, 1),
+            shape_native=(5, 1),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == np.array([0, 1, 3, 5, 8])
+            mapper.pixelization_index_for_sub_slim_index == np.array([0, 1, 3, 5, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [],
@@ -342,22 +368,25 @@ class TestRectangularMapper:
         #  I_I_I_I
         #  I_I_I_I
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.0, -1.5], [1.0, -0.49], [0.49, -1.5], [-0.6, 0.0], [-1.0, 1.5]],
             pixel_scales=1.0,
-            shape_2d=(5, 1),
+            shape_native=(5, 1),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(4, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(4, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == np.array([0, 1, 3, 10, 11])
+            mapper.pixelization_index_for_sub_slim_index == np.array([0, 1, 3, 10, 11])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [],
@@ -377,22 +406,25 @@ class TestRectangularMapper:
         #  I_I_I_I_I
         #  I_I_I_I_I
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.0, -1.5], [1.0, -0.49], [0.32, -1.5], [-0.34, 0.49], [-1.0, 1.5]],
             pixel_scales=1.0,
-            shape_2d=(5, 1),
+            shape_native=(5, 1),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 4), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 4), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == np.array([0, 1, 4, 10, 11])
+            mapper.pixelization_index_for_sub_slim_index == np.array([0, 1, 4, 10, 11])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [],
@@ -413,7 +445,7 @@ class TestRectangularMapper:
         # -(1/3) to (1/3) I_I_I_I
         #  (1/3) to 1.0   I_I_I_I
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.0, -1.0],
                 [1.0, 0.0],
@@ -426,19 +458,23 @@ class TestRectangularMapper:
                 [-1.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -458,7 +494,7 @@ class TestRectangularMapper:
         #  I_I_I_I Boundaries for pixels x = 1 and y = 1 - (1/3) to (1/3)
         #  I_I_I_I Boundaries for pixels x = 2 and y = 2 - (1/3)" to 1.0"
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [2.0, 0.0],
                 [2.0, 1.0],
@@ -471,19 +507,23 @@ class TestRectangularMapper:
                 [0.0, 2.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
+            mapper.pixelization_index_for_sub_slim_index
             == np.array([0, 1, 2, 3, 4, 5, 6, 7, 8])
         ).all()
 
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [2],
@@ -502,21 +542,24 @@ class TestRectangularMapper:
         #  I_I_I_I
         #  I_I_I_I
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[3.0, -0.5], [3.0, 0.51], [2.49, -0.5], [1.4, 1.0], [1.0, 2.5]],
             pixel_scales=1.0,
-            shape_2d=(5, 1),
+            shape_native=(5, 1),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(4, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(4, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
         assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == np.array([0, 1, 3, 10, 11])
+            mapper.pixelization_index_for_sub_slim_index == np.array([0, 1, 3, 10, 11])
         ).all()
-        assert mapper.all_sub_mask_1d_indexes_for_pixelization_1d_index == [
+        assert mapper.all_sub_slim_indexes_for_pixelization_index == [
             [0],
             [1],
             [],
@@ -534,7 +577,7 @@ class TestRectangularMapper:
     def test__reconstructed_pixelization__3x3_pixelization__solution_vector_ascending(
         self,
     ):
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [2.0, -1.0],
                 [2.0, 0.0],
@@ -547,19 +590,23 @@ class TestRectangularMapper:
                 [-2.0, 1.0],
             ],
             pixel_scales=1.0,
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 3), grid=grid)
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid
+        )
 
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
 
-        recon_pix = mapper.reconstructed_pixelization_from_solution_vector(
+        recon_pix = mapper.reconstruction_from(
             solution_vector=np.array([1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0])
         )
 
         assert (
-            recon_pix.in_2d
+            recon_pix.native
             == np.array([[1.0, 2.0, 3.0], [4.0, 5.0, 6.0], [7.0, 8.0, 9.0]])
         ).all()
         assert recon_pix.pixel_scales == pytest.approx((4.0 / 3.0, 2.0 / 3.0), 1e-2)
@@ -567,55 +614,61 @@ class TestRectangularMapper:
 
     def test__reconstructed_pixelization__compare_to_imaging_util(self):
 
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.0, 1.0], [1.0, 1.0], [1.0, 1.0], [1.0, 1.0]],
             pixel_scales=1.0,
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
         )
 
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(4, 3), grid=grid)
-
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
-
-        solution = np.array(
-            [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
-        )
-        recon_pix = mapper.reconstructed_pixelization_from_solution_vector(
-            solution_vector=solution
-        )
-        recon_pix_util = aa.util.array.sub_array_2d_from(
-            sub_array_1d=solution,
-            mask=np.full(fill_value=False, shape=(4, 3)),
-            sub_size=1,
-        )
-        assert (recon_pix.in_2d == recon_pix_util).all()
-        assert recon_pix.shape_2d == (4, 3)
-
-        pixelization_grid = aa.GridRectangular.overlay_grid(shape_2d=(3, 4), grid=grid)
-
-        mapper = aa.Mapper(grid=grid, pixelization_grid=pixelization_grid)
-
-        solution = np.array(
-            [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
-        )
-        recon_pix = mapper.reconstructed_pixelization_from_solution_vector(
-            solution_vector=solution
-        )
-        recon_pix_util = aa.util.array.sub_array_2d_from(
-            sub_array_1d=solution,
-            mask=np.full(fill_value=False, shape=(3, 4)),
-            sub_size=1,
-        )
-        assert (recon_pix.in_2d == recon_pix_util).all()
-        assert recon_pix.shape_2d == (3, 4)
-
-    def test__pixel_signals__compare_to_mapper_util(self, grid_7x7, image_7x7):
-        pixelization_grid = aa.GridRectangular.overlay_grid(
-            shape_2d=(3, 3), grid=grid_7x7
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(4, 3), grid=grid
         )
 
         mapper = aa.Mapper(
-            grid=grid_7x7, pixelization_grid=pixelization_grid, hyper_image=image_7x7
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
+
+        solution = np.array(
+            [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
+        )
+        recon_pix = mapper.reconstruction_from(solution_vector=solution)
+        recon_pix_util = aa.util.array.sub_array_2d_from(
+            sub_array_2d_slim=solution,
+            mask_2d=np.full(fill_value=False, shape=(4, 3)),
+            sub_size=1,
+        )
+        assert (recon_pix.native == recon_pix_util).all()
+        assert recon_pix.shape_native == (4, 3)
+
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 4), grid=grid
+        )
+
+        mapper = aa.Mapper(
+            source_grid_slim=grid, source_pixelization_grid=pixelization_grid
+        )
+
+        solution = np.array(
+            [1.0, 2.0, 3.0, 4.0, 5.0, 6.0, 7.0, 8.0, 9.0, 1.0, 2.0, 3.0]
+        )
+        recon_pix = mapper.reconstruction_from(solution_vector=solution)
+        recon_pix_util = aa.util.array.sub_array_2d_from(
+            sub_array_2d_slim=solution,
+            mask_2d=np.full(fill_value=False, shape=(3, 4)),
+            sub_size=1,
+        )
+        assert (recon_pix.native == recon_pix_util).all()
+        assert recon_pix.shape_native == (3, 4)
+
+    def test__pixel_signals__compare_to_mapper_util(self, grid_7x7, image_7x7):
+        pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            shape_native=(3, 3), grid=grid_7x7
+        )
+
+        mapper = aa.Mapper(
+            source_grid_slim=grid_7x7,
+            source_pixelization_grid=pixelization_grid,
+            hyper_data=image_7x7,
         )
 
         pixel_signals = mapper.pixel_signals_from_signal_scale(signal_scale=2.0)
@@ -623,8 +676,8 @@ class TestRectangularMapper:
         pixel_signals_util = aa.util.mapper.adaptive_pixel_signals_from(
             pixels=9,
             signal_scale=2.0,
-            pixelization_1d_index_for_sub_mask_1d_index=mapper.pixelization_1d_index_for_sub_mask_1d_index,
-            mask_1d_index_for_sub_mask_1d_index=grid_7x7.regions._mask_1d_index_for_sub_mask_1d_index,
+            pixelization_index_for_sub_slim_index=mapper.pixelization_index_for_sub_slim_index,
+            slim_index_for_sub_slim_index=grid_7x7.mask._slim_index_for_sub_slim_index,
             hyper_image=image_7x7,
         )
 
@@ -632,32 +685,33 @@ class TestRectangularMapper:
 
     def test__image_from_source__different_types_of_lists_input(self, sub_grid_7x7):
 
-        rectangular_pixelization_grid = aa.GridRectangular.overlay_grid(
-            grid=sub_grid_7x7, shape_2d=(3, 3)
+        rectangular_pixelization_grid = aa.Grid2DRectangular.overlay_grid(
+            grid=sub_grid_7x7, shape_native=(3, 3)
         )
         rectangular_mapper = aa.Mapper(
-            grid=sub_grid_7x7, pixelization_grid=rectangular_pixelization_grid
+            source_grid_slim=sub_grid_7x7,
+            source_pixelization_grid=rectangular_pixelization_grid,
         )
 
-        image_pixel_indexes = rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
-            source_pixel_indexes=[0, 1]
+        full_indexes = rectangular_mapper.slim_indexes_from_pixelization_indexes(
+            pixelization_indexes=[0, 1]
         )
 
-        assert image_pixel_indexes == [0, 1, 2, 3, 4, 5, 6, 7]
+        assert full_indexes == [0, 1, 2, 3, 4, 5, 6, 7]
 
-        image_pixel_indexes = rectangular_mapper.image_pixel_indexes_from_source_pixel_indexes(
-            source_pixel_indexes=[[0], [4]]
+        full_indexes = rectangular_mapper.slim_indexes_from_pixelization_indexes(
+            pixelization_indexes=[[0], [4]]
         )
 
-        assert image_pixel_indexes == [[0, 1, 2, 3], [16, 17, 18, 19]]
+        assert full_indexes == [[0, 1, 2, 3], [16, 17, 18, 19]]
 
 
 class TestVoronoiMapper:
     def test__grid_to_pixel_pixels_via_nearest_neighbour__case1__correct_pairs(self):
         pixel_centers = np.array([[1.0, 1.0], [-1.0, 1.0], [-1.0, -1.0], [1.0, -1.0]])
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [[1.1, 1.1], [-1.1, 1.1], [-1.1, -1.1], [1.1, -1.1]],
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=1.0,
         )
 
@@ -670,7 +724,7 @@ class TestVoronoiMapper:
 
     def test__grid_to_pixel_pixels_via_nearest_neighbour___case2__correct_pairs(self):
         pixel_centers = np.array([[1.0, 1.0], [-1.0, 1.0], [-1.0, -1.0], [1.0, -1.0]])
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [1.1, 1.1],
                 [-1.1, 1.1],
@@ -681,7 +735,7 @@ class TestVoronoiMapper:
                 [-0.9, 0.9],
                 [0.9, 0.9],
             ],
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=0.1,
         )
 
@@ -700,7 +754,7 @@ class TestVoronoiMapper:
         pixel_centers = np.array(
             [[1.0, 1.0], [-1.0, 1.0], [-1.0, -1.0], [1.0, -1.0], [0.0, 0.0], [2.0, 2.0]]
         )
-        grid = aa.Grid.manual_1d(
+        grid = aa.Grid2D.manual_slim(
             [
                 [0.1, 0.1],
                 [-0.1, -0.1],
@@ -709,7 +763,7 @@ class TestVoronoiMapper:
                 [1.01, 1.01],
                 [1.51, 1.51],
             ],
-            shape_2d=(3, 2),
+            shape_native=(3, 2),
             pixel_scales=1.0,
         )
 
@@ -723,9 +777,9 @@ class TestVoronoiMapper:
         assert sub_to_pix[5] == 5
 
     def test__sub_to_pix_of_mapper_matches_nearest_neighbor_calculation(self, grid_7x7):
-        pixelization_grid = aa.Grid.manual_1d(
+        pixelization_grid = aa.Grid2D.manual_slim(
             [[0.1, 0.1], [1.1, 0.1], [2.1, 0.1], [0.1, 1.1], [1.1, 1.1], [2.1, 1.1]],
-            shape_2d=(3, 2),
+            shape_native=(3, 2),
             pixel_scales=1.0,
         )
 
@@ -733,40 +787,43 @@ class TestVoronoiMapper:
             grid_7x7, pixelization_grid
         )
 
-        nearest_pixelization_1d_index_for_mask_1d_index = np.array(
+        nearest_pixelization_index_for_slim_index = np.array(
             [0, 0, 1, 0, 0, 1, 2, 2, 3]
         )
 
-        pixelization_grid = aa.GridVoronoi(
+        pixelization_grid = aa.Grid2DVoronoi(
             grid=pixelization_grid,
-            nearest_pixelization_1d_index_for_mask_1d_index=nearest_pixelization_1d_index_for_mask_1d_index,
-        )
-
-        mapper = aa.Mapper(grid=grid_7x7, pixelization_grid=pixelization_grid)
-
-        assert (
-            mapper.pixelization_1d_index_for_sub_mask_1d_index
-            == sub_to_pix_nearest_neighbour
-        ).all()
-
-    def test__pixel_scales___for_voronoi_mapper(self, grid_7x7, image_7x7):
-        pixelization_grid = aa.Grid.manual_1d(
-            [[0.1, 0.1], [1.1, 0.1], [2.1, 0.1], [0.1, 1.1], [1.1, 1.1], [2.1, 1.1]],
-            shape_2d=(3, 2),
-            pixel_scales=1.0,
-        )
-
-        nearest_pixelization_1d_index_for_mask_1d_index = np.array(
-            [0, 0, 1, 0, 0, 1, 2, 2, 3]
-        )
-
-        pixelization_grid = aa.GridVoronoi(
-            grid=pixelization_grid,
-            nearest_pixelization_1d_index_for_mask_1d_index=nearest_pixelization_1d_index_for_mask_1d_index,
+            nearest_pixelization_index_for_slim_index=nearest_pixelization_index_for_slim_index,
         )
 
         mapper = aa.Mapper(
-            grid=grid_7x7, pixelization_grid=pixelization_grid, hyper_image=image_7x7
+            source_grid_slim=grid_7x7, source_pixelization_grid=pixelization_grid
+        )
+
+        assert (
+            mapper.pixelization_index_for_sub_slim_index == sub_to_pix_nearest_neighbour
+        ).all()
+
+    def test__pixel_scales___for_voronoi_mapper(self, grid_7x7, image_7x7):
+        pixelization_grid = aa.Grid2D.manual_slim(
+            [[0.1, 0.1], [1.1, 0.1], [2.1, 0.1], [0.1, 1.1], [1.1, 1.1], [2.1, 1.1]],
+            shape_native=(3, 2),
+            pixel_scales=1.0,
+        )
+
+        nearest_pixelization_index_for_slim_index = np.array(
+            [0, 0, 1, 0, 0, 1, 2, 2, 3]
+        )
+
+        pixelization_grid = aa.Grid2DVoronoi(
+            grid=pixelization_grid,
+            nearest_pixelization_index_for_slim_index=nearest_pixelization_index_for_slim_index,
+        )
+
+        mapper = aa.Mapper(
+            source_grid_slim=grid_7x7,
+            source_pixelization_grid=pixelization_grid,
+            hyper_data=image_7x7,
         )
 
         pixel_signals = mapper.pixel_signals_from_signal_scale(signal_scale=2.0)
@@ -774,8 +831,8 @@ class TestVoronoiMapper:
         pixel_signals_util = aa.util.mapper.adaptive_pixel_signals_from(
             pixels=6,
             signal_scale=2.0,
-            pixelization_1d_index_for_sub_mask_1d_index=mapper.pixelization_1d_index_for_sub_mask_1d_index,
-            mask_1d_index_for_sub_mask_1d_index=grid_7x7.regions._mask_1d_index_for_sub_mask_1d_index,
+            pixelization_index_for_sub_slim_index=mapper.pixelization_index_for_sub_slim_index,
+            slim_index_for_sub_slim_index=grid_7x7.mask._slim_index_for_sub_slim_index,
             hyper_image=image_7x7,
         )
 
