@@ -10,7 +10,7 @@ path = "{}/".format(os.path.dirname(os.path.realpath(__file__)))
 class TestFrameAPI:
     def test__manual__makes_frame_using_inputs__include_rotations(self):
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(1, 0),
@@ -28,10 +28,10 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, False], [False, False]])).all()
         assert (frame.original_orientation == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
-        assert (frame.in_2d == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
-        assert frame.in_2d.scans.parallel_overscan == (0, 1, 0, 1)
+        assert (frame.native == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
+        assert frame.native.scans.parallel_overscan == (0, 1, 0, 1)
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(0, 0),
@@ -50,7 +50,7 @@ class TestFrameAPI:
         assert (frame.mask == np.array([[False, False], [False, False]])).all()
         assert (frame.original_orientation == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(1, 1),
@@ -69,7 +69,7 @@ class TestFrameAPI:
         assert (frame.mask == np.array([[False, False], [False, False]])).all()
         assert (frame.original_orientation == np.array([[1.0, 2.0], [3.0, 4.0]])).all()
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(0, 1),
@@ -90,9 +90,9 @@ class TestFrameAPI:
 
     def test__full_ones_zeros__makes_frame_using_inputs(self):
 
-        frame = aa.Frame.full(
+        frame = aa.Frame2D.full(
             fill_value=8.0,
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
@@ -109,8 +109,8 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, False], [False, False]])).all()
 
-        frame = aa.Frame.ones(
-            shape_2d=(2, 2),
+        frame = aa.Frame2D.ones(
+            shape_native=(2, 2),
             pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
@@ -127,8 +127,8 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, False], [False, False]])).all()
 
-        frame = aa.Frame.zeros(
-            shape_2d=(2, 2),
+        frame = aa.Frame2D.zeros(
+            shape_native=(2, 2),
             pixel_scales=1.0,
             roe_corner=(1, 0),
             scans=aa.Scans(
@@ -147,7 +147,7 @@ class TestFrameAPI:
 
     def test__extracted_frame_from_frame_and_extraction_region(self):
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0, 3.0], [4.0, 5.0, 6.0], [7.0, 8.0, 9.0]],
             pixel_scales=1.0,
             roe_corner=(1, 0),
@@ -158,8 +158,8 @@ class TestFrameAPI:
             ),
         )
 
-        frame = aa.Frame.extracted_frame_from_frame_and_extraction_region(
-            frame=frame, extraction_region=aa.Region(region=(1, 3, 1, 3))
+        frame = aa.Frame2D.extracted_frame_from_frame_and_extraction_region(
+            frame=frame, extraction_region=aa.Region2D(region=(1, 3, 1, 3))
         )
 
         assert (frame == np.array([[5.0, 6.0], [8.0, 9.0]])).all()
@@ -175,7 +175,7 @@ class TestFrameAPI:
 
         mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
-        frame = aa.Frame.manual_mask(
+        frame = aa.Frame2D.manual_mask(
             array=[[1.0, 2.0], [3.0, 4.0]],
             mask=mask,
             roe_corner=(1, 0),
@@ -193,7 +193,7 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, True], [False, False]])).all()
 
-        frame = aa.Frame.manual_mask(
+        frame = aa.Frame2D.manual_mask(
             array=[[1.0, 2.0], [3.0, 4.0]],
             mask=mask,
             roe_corner=(0, 0),
@@ -211,7 +211,7 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[False, False], [False, True]])).all()
 
-        frame = aa.Frame.manual_mask(
+        frame = aa.Frame2D.manual_mask(
             array=[[1.0, 2.0], [3.0, 4.0]],
             mask=mask,
             roe_corner=(1, 1),
@@ -229,7 +229,7 @@ class TestFrameAPI:
         assert frame.scans.serial_overscan == (0, 2, 0, 2)
         assert (frame.mask == np.array([[True, False], [False, False]])).all()
 
-        frame = aa.Frame.manual_mask(
+        frame = aa.Frame2D.manual_mask(
             array=[[1.0, 2.0], [3.0, 4.0]],
             mask=mask,
             roe_corner=(0, 1),
@@ -251,7 +251,7 @@ class TestFrameAPI:
 
         mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(1, 0),
@@ -262,7 +262,7 @@ class TestFrameAPI:
             ),
         )
 
-        frame = aa.Frame.from_frame(frame=frame, mask=mask)
+        frame = aa.Frame2D.from_frame(frame=frame, mask=mask)
 
         assert (frame == np.array([[1.0, 0.0], [3.0, 4.0]])).all()
         assert frame.original_roe_corner == (1, 0)
@@ -273,7 +273,7 @@ class TestFrameAPI:
 
         mask = aa.Mask2D.manual(mask=[[False, True], [False, False]], pixel_scales=1.0)
 
-        frame = aa.Frame.manual(
+        frame = aa.Frame2D.manual(
             array=[[1.0, 2.0], [3.0, 4.0]],
             pixel_scales=1.0,
             roe_corner=(0, 0),
@@ -284,7 +284,7 @@ class TestFrameAPI:
             ),
         )
 
-        frame = aa.Frame.from_frame(frame=frame, mask=mask)
+        frame = aa.Frame2D.from_frame(frame=frame, mask=mask)
 
         assert (frame == np.array([[3.0, 0.0], [1.0, 2.0]])).all()
         assert frame.original_roe_corner == (0, 0)
