@@ -334,7 +334,7 @@ class TestBinnedArrays2d:
             == np.array([[(5.0 / 9.0), (4.0 / 9.0)], [(4.0 / 9.0), (4.0 / 9.0)]])
         ).all()
 
-        # Padded Array:
+        # Padded Array2D:
 
         # np.array([[0.0, 1.0, 1.0, 1.0],
         #           [0.0, 1.0, 2.0, 1.0]]
@@ -491,7 +491,7 @@ class TestBinnedArrays2d:
             )
         ).all()
 
-        # Padded Array:
+        # Padded Array2D:
 
         # np.array([[0.0, 1.0, 1.0, 1.0],
         #           [0.0, 1.0, 2.0, 1.0]]
@@ -616,7 +616,7 @@ class TestBinnedArrays2d:
         )
         assert (binned_array_2d == np.array([[5.0, 4.0], [4.0, 4.0]])).all()
 
-        # Padded Array:
+        # Padded Array2D:
 
         # np.array([[0.0, 1.0, 1.0, 1.0],
         #           [0.0, 1.0, 2.0, 1.0]]
@@ -727,7 +727,7 @@ class TestBinUpMask2d:
         binned_mask = aa.util.binning.bin_mask(mask=mask, bin_up_factor=3)
         assert (binned_mask == np.array([[False, True], [True, False]])).all()
 
-        # Padded Array:
+        # Padded Array2D:
 
         # np.array([[0.0, 1.0, 1.0, 1.0],
         #           [0.0, 1.0, 2.0, 1.0]]
@@ -745,10 +745,8 @@ class TestMask1DIndexForPaddedMask2dIndex:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        mask_1d_index_for_padded_mask_index = (
-            aa.util.binning.mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=1
-            )
+        mask_1d_index_for_padded_mask_index = aa.util.binning.mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=1
         )
 
         assert (
@@ -758,10 +756,8 @@ class TestMask1DIndexForPaddedMask2dIndex:
 
         mask = np.array([[False, False], [True, False], [True, False]])
 
-        mask_1d_index_for_padded_mask_index = (
-            aa.util.binning.mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=1
-            )
+        mask_1d_index_for_padded_mask_index = aa.util.binning.mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=1
         )
 
         assert (
@@ -772,10 +768,8 @@ class TestMask1DIndexForPaddedMask2dIndex:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        mask_1d_index_for_padded_mask_index = (
-            aa.util.binning.mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=3
-            )
+        mask_1d_index_for_padded_mask_index = aa.util.binning.mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=3
         )
 
         assert (
@@ -794,10 +788,8 @@ class TestMask1DIndexForPaddedMask2dIndex:
 
         mask = np.array([[False, False], [True, False], [True, False]])
 
-        mask_1d_index_for_padded_mask_index = (
-            aa.util.binning.mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=2
-            )
+        mask_1d_index_for_padded_mask_index = aa.util.binning.mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -811,10 +803,8 @@ class TestBinnedMask1dIndexesForMask2dIndex:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        binned_mask_1d_index_for_mask_index = (
-            aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_mask_1d_index_for_mask_index = aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -824,10 +814,8 @@ class TestBinnedMask1dIndexesForMask2dIndex:
 
         mask = np.full(fill_value=False, shape=(9, 9))
 
-        binned_mask_1d_index_for_mask_index = (
-            aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=3
-            )
+        binned_mask_1d_index_for_mask_index = aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=3
         )
 
         assert (
@@ -858,10 +846,8 @@ class TestBinnedMask1dIndexesForMask2dIndex:
             ]
         )
 
-        binned_mask_1d_index_for_mask_index = (
-            aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_mask_1d_index_for_mask_index = aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -880,10 +866,8 @@ class TestBinnedMask1dIndexesForMask2dIndex:
             ]
         )
 
-        binned_mask_1d_index_for_mask_index = (
-            aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_mask_1d_index_for_mask_index = aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -895,10 +879,8 @@ class TestBinnedMask1dIndexesForMask2dIndex:
 
         mask = np.full(fill_value=False, shape=(5, 5))
 
-        binned_mask_1d_index_for_mask_index = (
-            aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_mask_1d_index_for_mask_index = aa.util.binning.binned_mask_1d_index_for_padded_mask_index_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -921,10 +903,8 @@ class TestArray1DToBininedArray1d:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        binned_masked_array_1d_for_masked_array_1d = (
-            aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_masked_array_1d_for_masked_array_1d = aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -934,10 +914,8 @@ class TestArray1DToBininedArray1d:
 
         mask = np.full(fill_value=False, shape=(9, 9))
 
-        binned_masked_array_1d_for_masked_array_1d = (
-            aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
-                mask=mask, bin_up_factor=3
-            )
+        binned_masked_array_1d_for_masked_array_1d = aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
+            mask=mask, bin_up_factor=3
         )
 
         assert (
@@ -1040,10 +1018,8 @@ class TestArray1DToBininedArray1d:
             ]
         )
 
-        binned_masked_array_1d_for_masked_array_1d = (
-            aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_masked_array_1d_for_masked_array_1d = aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -1061,10 +1037,8 @@ class TestArray1DToBininedArray1d:
             ]
         )
 
-        binned_masked_array_1d_for_masked_array_1d = (
-            aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_masked_array_1d_for_masked_array_1d = aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -1075,10 +1049,8 @@ class TestArray1DToBininedArray1d:
 
         mask = np.full(fill_value=False, shape=(5, 5))
 
-        binned_masked_array_1d_for_masked_array_1d = (
-            aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        binned_masked_array_1d_for_masked_array_1d = aa.util.binning.binned_masked_array_1d_for_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -1120,10 +1092,8 @@ class TestBinnedMaskArrayToArray:
 
         mask = np.full(fill_value=False, shape=(4, 4))
 
-        masked_array_1d_for_binned_masked_array_1d = (
-            aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        masked_array_1d_for_binned_masked_array_1d = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
@@ -1132,10 +1102,8 @@ class TestBinnedMaskArrayToArray:
 
         mask = np.full(fill_value=False, shape=(9, 9))
 
-        masked_array_1d_for_binned_masked_array_1d = (
-            aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
-                mask=mask, bin_up_factor=3
-            )
+        masked_array_1d_for_binned_masked_array_1d = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
+            mask=mask, bin_up_factor=3
         )
 
         assert (
@@ -1154,10 +1122,8 @@ class TestBinnedMaskArrayToArray:
             ]
         )
 
-        masked_array_1d_for_binned_masked_array_1d = (
-            aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        masked_array_1d_for_binned_masked_array_1d = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (masked_array_1d_for_binned_masked_array_1d == np.array([0, 3])).all()
@@ -1173,10 +1139,8 @@ class TestBinnedMaskArrayToArray:
             ]
         )
 
-        masked_array_1d_for_binned_masked_array_1d = (
-            aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        masked_array_1d_for_binned_masked_array_1d = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (masked_array_1d_for_binned_masked_array_1d == np.array([0, 3])).all()
@@ -1185,10 +1149,8 @@ class TestBinnedMaskArrayToArray:
 
         mask = np.full(fill_value=False, shape=(5, 5))
 
-        masked_array_1d_for_binned_masked_array_1d = (
-            aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
-                mask=mask, bin_up_factor=2
-            )
+        masked_array_1d_for_binned_masked_array_1d = aa.util.binning.masked_array_1d_for_binned_masked_array_1d_from(
+            mask=mask, bin_up_factor=2
         )
 
         assert (
