@@ -1,38 +1,304 @@
-import numpy as np
-import pytest
-
 import autoarray as aa
 
 
-class TestCoordinates:
+class TestCoordinates1D:
     def test__central_pixel__depends_on_shape_pixel_scale_and_origin(self):
 
-        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_from(
-            shape=(3,)
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_1d_from(
+            shape_slim=(3,)
         )
 
         assert central_pixel_coordinates == (1,)
 
-        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_from(
-            shape=(3, 3)
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_1d_from(
+            shape_slim=(4,)
+        )
+
+        assert central_pixel_coordinates == (1.5,)
+
+    def test__pixel_coordinates_1d_from(self):
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(1.0,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(1.0,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-1.0,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.0,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(3.0,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert pixel_coordinates == (2,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-3.0,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(3.0,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert pixel_coordinates == (2,)
+
+    def test__pixel_coordinates_1d_from__scaled_are_pixel_corners(self):
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-1.99,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-0.01,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.01,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-1.99,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-0.01,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.01,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(1.99,), shape_slim=(2,), pixel_scales=(2.0,)
+        )
+
+        assert pixel_coordinates == (1,)
+
+    def test__pixel_coordinates_1d_from___scaled_are_pixel_centres__nonzero_centre(
+        self,
+    ):
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.0,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(2.0,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.0,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(3.0,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(6.0,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert pixel_coordinates == (2,)
+
+    def test__pixel_coordinates_1d_from__scaled_are_pixel_corners__nonzero_centre(
+        self,
+    ):
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(-0.99,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(0.99,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (0,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(1.01,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(2.99,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(1.01,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+        pixel_coordinates = aa.util.geometry.pixel_coordinates_1d_from(
+            scaled_coordinates_1d=(2.99,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert pixel_coordinates == (1,)
+
+    def test__scaled_coordinates_1d_from___scaled_are_pixel_centres__nonzero_centre(
+        self,
+    ):
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(0,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert scaled_coordinates == (-3.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(1,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert scaled_coordinates == (0.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(2,), shape_slim=(3,), pixel_scales=(3.0,)
+        )
+
+        assert scaled_coordinates == (3.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(0,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert scaled_coordinates == (0.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(1,),
+            shape_slim=(2,),
+            pixel_scales=(2.0,),
+            origins=(1.0,),
+        )
+
+        assert scaled_coordinates == (2.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(0,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert scaled_coordinates == (0.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(1,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert scaled_coordinates == (3.0,)
+
+        scaled_coordinates = aa.util.geometry.scaled_coordinates_1d_from(
+            pixel_coordinates_1d=(2,),
+            shape_slim=(3,),
+            pixel_scales=(3.0,),
+            origins=(3.0,),
+        )
+
+        assert scaled_coordinates == (6.0,)
+
+
+class TestCoordinates2D:
+    def test__central_pixel__depends_on_shape_pixel_scale_and_origin(self):
+
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_2d_from(
+            shape_native=(3, 3)
         )
 
         assert central_pixel_coordinates == (1, 1)
 
-        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_from(
-            shape=(3, 3)
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_2d_from(
+            shape_native=(3, 3)
         )
 
         assert central_pixel_coordinates == (1, 1)
 
-        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_from(
-            shape=(4, 4)
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_2d_from(
+            shape_native=(4, 4)
         )
 
         assert central_pixel_coordinates == (1.5, 1.5)
 
-        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_from(
-            shape=(4, 4)
+        central_pixel_coordinates = aa.util.geometry.central_pixel_coordinates_2d_from(
+            shape_native=(4, 4)
         )
 
         assert central_pixel_coordinates == (1.5, 1.5)
@@ -40,79 +306,105 @@ class TestCoordinates:
     def test__pixel_coordinates_2d_from(self):
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(1.0, -1.0), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(1.0, -1.0),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(1.0, 1.0), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(1.0, 1.0),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(-1.0, -1.0), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(-1.0, -1.0),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (1, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(-1.0, 1.0), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(-1.0, 1.0),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (1, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(3.0, -3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(3.0, -3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (0, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(3.0, 0.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(3.0, 0.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(3.0, 3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(3.0, 3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (0, 2)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(0.0, -3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(0.0, -3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (1, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(0.0, 0.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(0.0, 0.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (1, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(0.0, 3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(0.0, 3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (1, 2)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(-3.0, -3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(-3.0, -3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (2, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(-3.0, 0.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(-3.0, 0.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (2, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(-3.0, 3.0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            scaled_coordinates_2d=(-3.0, 3.0),
+            shape_native=(3, 3),
+            pixel_scales=(3.0, 3.0),
         )
 
         assert pixel_coordinates == (2, 2)
@@ -121,7 +413,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.99, -1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -129,7 +421,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.99, -0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -137,7 +429,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.01, -1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -145,39 +437,47 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.01, -0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 0)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(2.01, 0.01), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(2.01, 0.01),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(2.01, 1.99), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(2.01, 1.99),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(0.01, 0.01), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(0.01, 0.01),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
-            scaled_coordinates_2d=(0.01, 1.99), shape_2d=(2, 2), pixel_scales=(2.0, 2.0)
+            scaled_coordinates_2d=(0.01, 1.99),
+            shape_native=(2, 2),
+            pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (0, 1)
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.01, -1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -185,14 +485,14 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.01, -0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
         assert pixel_coordinates == (1, 0)
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-1.99, -1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -200,7 +500,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-1.99, -0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -208,7 +508,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.01, 0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -216,7 +516,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.01, 1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -224,7 +524,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-1.99, 0.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -232,7 +532,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-1.99, 1.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
         )
 
@@ -244,7 +544,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(2.0, 0.0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -253,7 +553,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(2.0, 2.0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -262,7 +562,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.0, 0.0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -271,7 +571,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.0, 2.0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -280,7 +580,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(6.0, 0.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -289,7 +589,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(6.0, 3.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -298,7 +598,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(6.0, 6.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -307,7 +607,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(3.0, 0.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -316,7 +616,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(3.0, 3.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -325,7 +625,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(3.0, 6.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -334,7 +634,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.0, 0.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -343,7 +643,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.0, 3.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -352,7 +652,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.0, 6.0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -365,7 +665,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(2.99, -0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -374,7 +674,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(2.99, 0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -383,7 +683,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.01, -0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -392,7 +692,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.01, 0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -401,7 +701,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(3.01, 1.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -410,7 +710,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(3.01, 2.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -419,7 +719,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.01, 1.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -428,7 +728,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(1.01, 2.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -437,7 +737,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.99, -0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -446,7 +746,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.99, 0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -455,7 +755,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.99, -0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -464,7 +764,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.99, 0.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -473,7 +773,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.99, 1.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -482,7 +782,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(0.99, 2.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -491,7 +791,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.99, 1.01),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -500,7 +800,7 @@ class TestCoordinates:
 
         pixel_coordinates = aa.util.geometry.pixel_coordinates_2d_from(
             scaled_coordinates_2d=(-0.99, 2.99),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -512,62 +812,62 @@ class TestCoordinates:
     ):
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(0, 0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(0, 0), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (3.0, -3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(0, 1), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(0, 1), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (3.0, 0.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(0, 2), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(0, 2), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (3.0, 3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(1, 0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(1, 0), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (0.0, -3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(1, 1), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(1, 1), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (0.0, 0.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(1, 2), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(1, 2), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (0.0, 3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(2, 0), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(2, 0), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (-3.0, -3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(2, 1), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(2, 1), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (-3.0, 0.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
-            pixel_coordinates_2d=(2, 2), shape_2d=(3, 3), pixel_scales=(3.0, 3.0)
+            pixel_coordinates_2d=(2, 2), shape_native=(3, 3), pixel_scales=(3.0, 3.0)
         )
 
         assert scaled_coordinates == (-3.0, 3.0)
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(0, 0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -576,7 +876,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(0, 1),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -585,7 +885,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(1, 0),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -594,7 +894,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(1, 1),
-            shape_2d=(2, 2),
+            shape_native=(2, 2),
             pixel_scales=(2.0, 2.0),
             origins=(1.0, 1.0),
         )
@@ -603,7 +903,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(0, 0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -612,7 +912,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(0, 1),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -621,7 +921,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(0, 2),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -630,7 +930,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(1, 0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -639,7 +939,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(1, 1),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -648,7 +948,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(1, 2),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -657,7 +957,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(2, 0),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -666,7 +966,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(2, 1),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
@@ -675,7 +975,7 @@ class TestCoordinates:
 
         scaled_coordinates = aa.util.geometry.scaled_coordinates_2d_from(
             pixel_coordinates_2d=(2, 2),
-            shape_2d=(3, 3),
+            shape_native=(3, 3),
             pixel_scales=(3.0, 3.0),
             origins=(3.0, 3.0),
         )
