@@ -21,8 +21,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -52,8 +52,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [2, 2], [1, 1], [0, 2], [2, 0], [0, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -79,8 +79,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [1, 0], [1, 1], [1, 2], [2, 0], [2, 1], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -106,8 +106,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -137,8 +137,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 3], [2, 2]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -169,8 +169,8 @@ class TestUnmaskedSparseForSparse:
             [[0, 0], [0, 1], [0, 2], [0, 2], [0, 2], [1, 1], [2, 2], [3, 1]]
         )
 
-        total_masked_pixels = aa.util.mask.total_sparse_pixels_from(
-            mask=ma,
+        total_masked_pixels = aa.util.mask.total_sparse_pixels_2d_from(
+            mask_2d=ma,
             unmasked_sparse_grid_pixel_centres=unmasked_sparse_grid_pixel_centres,
         )
 
@@ -341,51 +341,39 @@ class TestRegularToSparse:
 
         regular_to_unmasked_sparse = np.array([0, 1, 2, 3, 4])
         sparse_for_unmasked_sparse = np.array([0, 1, 2, 3, 4])
-        sparse_1d_index_for_mask_1d_index = (
-            aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
-                regular_to_unmasked_sparse=regular_to_unmasked_sparse,
-                sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
-            )
+        sparse_index_for_slim_index = aa.util.sparse.sparse_slim_index_for_mask_slim_index_from(
+            regular_to_unmasked_sparse=regular_to_unmasked_sparse,
+            sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
 
-        assert (sparse_1d_index_for_mask_1d_index == np.array([0, 1, 2, 3, 4])).all()
+        assert (sparse_index_for_slim_index == np.array([0, 1, 2, 3, 4])).all()
 
         regular_to_unmasked_sparse = np.array([0, 1, 2, 3, 4])
         sparse_for_unmasked_sparse = np.array([0, 1, 5, 7, 18])
-        sparse_1d_index_for_mask_1d_index = (
-            aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
-                regular_to_unmasked_sparse=regular_to_unmasked_sparse,
-                sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
-            )
+        sparse_index_for_slim_index = aa.util.sparse.sparse_slim_index_for_mask_slim_index_from(
+            regular_to_unmasked_sparse=regular_to_unmasked_sparse,
+            sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
 
-        assert (sparse_1d_index_for_mask_1d_index == np.array([0, 1, 5, 7, 18])).all()
+        assert (sparse_index_for_slim_index == np.array([0, 1, 5, 7, 18])).all()
 
         regular_to_unmasked_sparse = np.array([1, 1, 1, 1, 2])
         sparse_for_unmasked_sparse = np.array([0, 10, 15, 3, 4])
-        sparse_1d_index_for_mask_1d_index = (
-            aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
-                regular_to_unmasked_sparse=regular_to_unmasked_sparse,
-                sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
-            )
+        sparse_index_for_slim_index = aa.util.sparse.sparse_slim_index_for_mask_slim_index_from(
+            regular_to_unmasked_sparse=regular_to_unmasked_sparse,
+            sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
 
-        assert (
-            sparse_1d_index_for_mask_1d_index == np.array([10, 10, 10, 10, 15])
-        ).all()
+        assert (sparse_index_for_slim_index == np.array([10, 10, 10, 10, 15])).all()
 
         regular_to_unmasked_sparse = np.array([5, 6, 7, 8, 9])
         sparse_for_unmasked_sparse = np.array([0, 1, 2, 3, 4, 19, 18, 17, 16, 15])
-        sparse_1d_index_for_mask_1d_index = (
-            aa.util.sparse.sparse_1d_index_for_mask_1d_index_from(
-                regular_to_unmasked_sparse=regular_to_unmasked_sparse,
-                sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
-            )
+        sparse_index_for_slim_index = aa.util.sparse.sparse_slim_index_for_mask_slim_index_from(
+            regular_to_unmasked_sparse=regular_to_unmasked_sparse,
+            sparse_for_unmasked_sparse=sparse_for_unmasked_sparse,
         )
 
-        assert (
-            sparse_1d_index_for_mask_1d_index == np.array([19, 18, 17, 16, 15])
-        ).all()
+        assert (sparse_index_for_slim_index == np.array([19, 18, 17, 16, 15])).all()
 
 
 class TestSparseGridFromUnmaskedSparseGrid:
